@@ -216,7 +216,8 @@ Kid3Cli::Kid3Cli(Kid3Application* app,
          << new TagToOtherTagCommand(this)
          << new CopyCommand(this)
          << new PasteCommand(this)
-         << new RemoveCommand(this);
+         << new RemoveCommand(this)
+         << new ConfigCommand(this);
   connect(m_app, &Kid3Application::fileSelectionUpdateRequested,
           this, &Kid3Cli::updateSelectedFiles);
   connect(m_app, &Kid3Application::selectedFilesUpdated,
@@ -484,7 +485,7 @@ void Kid3Cli::writeFileInformation(int tagMask)
           ft->index(row, FrameTableModel::CI_Value).data().toString();
       if (!(tagNr == Frame::Tag_1 ? value.isEmpty() : value.isNull())) {
         QVariant background = ft->index(row, FrameTableModel::CI_Enable)
-            .data(Qt::BackgroundColorRole);
+            .data(Qt::BackgroundRole);
         CoreTaggedFileIconProvider* colorProvider =
             m_app->getPlatformTools()->iconProvider();
         bool changed = colorProvider &&
@@ -504,7 +505,7 @@ void Kid3Cli::writeFileInformation(int tagMask)
                  });
     }
   }
-  writeResult(QVariantMap{{"taggedFile", map}});
+  writeResult(QVariantMap{{QLatin1String("taggedFile"), map}});
 }
 
 /**
@@ -517,7 +518,7 @@ void Kid3Cli::writeTagMask()
   FOR_TAGS_IN_MASK(tagNr, m_tagMask) {
     tags.append(tagNr + 1);
   }
-  writeResult(QVariantMap{{"tags", tags}});
+  writeResult(QVariantMap{{QLatin1String("tags"), tags}});
 }
 
 /**
@@ -557,7 +558,12 @@ QVariantList Kid3Cli::listFiles(const FileProxyModel* model,
     return lst;
 
   m_app->updateCurrentSelection();
+#if QT_VERSION >= 0x050e00
+  const QList<QPersistentModelIndex>& selLst = m_app->getCurrentSelection();
+  QSet<QPersistentModelIndex> selection(selLst.constBegin(), selLst.constEnd());
+#else
   QSet<QPersistentModelIndex> selection = m_app->getCurrentSelection().toSet();
+#endif
   for (int row = 0; row < model->rowCount(parent); ++row) {
     QModelIndex idx(model->index(row, 0, parent));
     QVariantMap map;
@@ -642,6 +648,15 @@ void Kid3Cli::writeResult(const QVariantMap& map)
   m_formatter->writeResult(map);
 }
 
+/**
+ * Write result of command.
+ * @param result result as boolean
+ */
+void Kid3Cli::writeResult(bool result)
+{
+  m_formatter->writeResult(result);
+}
+
 /**
  * Called when a command is finished.
  */
