@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,11 +25,10 @@
  */
 
 #include "kdeconfigdialog.h"
+#include <QPushButton>
+#include <KConfigSkeleton>
 #include "contexthelp.h"
 #include "configdialogpages.h"
-#if QT_VERSION >= 0x050000
-#include <QPushButton>
-#endif
 
 /**
  * Constructor.
@@ -41,48 +40,41 @@
  */
 KdeConfigDialog::KdeConfigDialog(IPlatformTools* platformTools,
                                  QWidget* parent, QString& caption,
-                                 KConfigSkeleton* configSkeleton) :
-  KConfigDialog(parent, QLatin1String("configure"), configSkeleton),
-  m_pages(new ConfigDialogPages(platformTools, this))
+                                 KConfigSkeleton* configSkeleton)
+  : KConfigDialog(parent, QLatin1String("configure"), configSkeleton),
+    m_pages(new ConfigDialogPages(platformTools, this))
 {
   setObjectName(QLatin1String("ConfigDialog"));
   setWindowTitle(caption);
   setSizeGripEnabled(true);
 
-  addPage(m_pages->createTagsPage(), tr("Tags"), QLatin1String("applications-multimedia"));
-  addPage(m_pages->createFilesPage(), tr("Files"), QLatin1String("document-save"));
-  addPage(m_pages->createActionsPage(), tr("User Actions"), QLatin1String("preferences-other"));
-  addPage(m_pages->createNetworkPage(), tr("Network"), QLatin1String("preferences-system-network"));
-  addPage(m_pages->createPluginsPage(), tr("Plugins"), QLatin1String("preferences-plugin"));
+  addPage(m_pages->createTagsPage(), tr("Tags"),
+          QLatin1String("applications-multimedia"));
+  addPage(m_pages->createFilesPage(), tr("Files"),
+          QLatin1String("document-save"));
+  addPage(m_pages->createActionsPage(), tr("User Actions"),
+          QLatin1String("preferences-other"));
+  addPage(m_pages->createNetworkPage(), tr("Network"),
+          QLatin1String("preferences-system-network"));
+  addPage(m_pages->createPluginsPage(), tr("Plugins"),
+          QLatin1String("preferences-plugin"));
 
-#if QT_VERSION >= 0x050000
   setStandardButtons(QDialogButtonBox::RestoreDefaults |
                      QDialogButtonBox::Ok | QDialogButtonBox::Cancel |
                      QDialogButtonBox::Help);
   if (const QDialogButtonBox* buttons = buttonBox()) {
     if (QPushButton* helpButton = buttons->button(QDialogButtonBox::Help)) {
-      connect(helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
+      connect(helpButton, &QAbstractButton::clicked,
+              this, &KdeConfigDialog::slotHelp);
     }
     if (QPushButton* defaultsButton =
         buttons->button(QDialogButtonBox::RestoreDefaults)) {
-      connect(defaultsButton, SIGNAL(clicked()),
-              m_pages, SLOT(setDefaultConfig()));
+      connect(defaultsButton, &QAbstractButton::clicked,
+              m_pages, &ConfigDialogPages::setDefaultConfig);
     }
   }
-#else
-  setButtons(Default | Ok | Cancel | Help);
-  enableButton(Default, true);
-  connect(this, SIGNAL(defaultClicked()), m_pages, SLOT(setDefaultConfig()));
-  setHelp(QLatin1String("configure-kid3"));
-#endif
 }
 
-/**
- * Destructor.
- */
-KdeConfigDialog::~KdeConfigDialog()
-{}
-
 /**
  * Set values in dialog from current configuration.
  */
