@@ -40,6 +40,7 @@
 #include "config.h"
 #include "kid3form.h"
 #include "filelist.h"
+#include "sectionactions.h"
 #include "kid3application.h"
 #include "kdeconfigdialog.h"
 #include "guiconfig.h"
@@ -197,7 +198,12 @@ void KdeMainWindow::initActions()
   action = new QAction(QIcon::fromTheme(QLatin1String("view-refresh")),
                        tr("Re&load"), this);
   action->setStatusTip(tr("Reload folder"));
-  action->setShortcut(QKeySequence::Refresh);
+  // When using the KDE version on GNOME, a dialog appears "There are two
+  // actions (Replace..., Reload) that want to use the same shortcut (Ctrl+R)".
+  // Avoid this by assigning Qt::Key_F5 instead of QKeySequence::Refresh.
+  // The section "Standard Shortcuts" in the QKeySequence documentation lists
+  // F5 as a key for "Refresh" on all platforms.
+  action->setShortcut(Qt::Key_F5);
   collection->addAction(QLatin1String("reload"), action);
   connect(action, &QAction::triggered,
           impl(), &BaseMainWindowImpl::slotFileReload);
@@ -330,6 +336,9 @@ void KdeMainWindow::initActions()
   action->setStatusTip(tr("Select all files in the current folder"));
   collection->addAction(QLatin1String("select_all_in_directory"), action);
   connect(action, &QAction::triggered, app(), &Kid3Application::selectAllInDirectory);
+  action = new QAction(tr("&Invert Selection"), this);
+  collection->addAction(QLatin1String("invert_selection"), action);
+  connect(action, &QAction::triggered, app(), &Kid3Application::invertSelection);
   action = new QAction(QIcon::fromTheme(QLatin1String("go-previous")),
                        tr("&Previous File"), this);
   action->setStatusTip(tr("Select previous file"));
@@ -418,13 +427,16 @@ void KdeMainWindow::initActions()
   action->setShortcut(QKeySequence(Qt::Key_F2));
   action->setShortcutContext(Qt::WidgetShortcut);
   connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::renameFile);
-  collection->addAction(QLatin1String("filelist_rename"), action);
+  // This action is not made configurable because its shortcut F2 conflicts
+  // with a section shortcut and there seems to be no way to avoid it with
+  // KShortcutsDialog. The same applies to the shortcut with the Delete key.
+  // collection->addAction(QLatin1String("filelist_rename"), action);
   form()->getFileList()->setRenameAction(action);
   action = new QAction(tr("&Move to Trash"), this);
   action->setShortcut(QKeySequence::Delete);
   action->setShortcutContext(Qt::WidgetShortcut);
   connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::deleteFile);
-  collection->addAction(QLatin1String("filelist_delete"), action);
+  // collection->addAction(QLatin1String("filelist_delete"), action);
   form()->getFileList()->setDeleteAction(action);
   action = new QAction(tr("Folder List") + QLatin1String(": ") + tr("Focus"),
                        this);
@@ -443,9 +455,45 @@ void KdeMainWindow::initActions()
   connect(&userActionsCfg, &UserActionsConfig::contextMenuCommandsChanged,
           fileList, &FileList::initUserActions);
 
+  const auto sectionShortcuts = SectionActions::defaultShortcuts();
+  QString actionPrefix = tr("Section") + QLatin1String(": ");
+  for (auto it = sectionShortcuts.constBegin();
+       it != sectionShortcuts.constEnd();
+       ++it) {
+    const auto& tpl = *it;
+    action = new QAction(actionPrefix + std::get<1>(tpl), this);
+    action->setShortcutContext(Qt::WidgetShortcut);
+    // The action is only used to configure the shortcuts. Disabling it will
+    // also avoid "that want to use the same shortcut" error dialogs.
+    action->setEnabled(false);
+    collection->setDefaultShortcut(action, std::get<2>(tpl));
+    collection->addAction(std::get<0>(tpl), action);
+  }
+
   createGUI();
 }
 
+/**
+ * Get keyboard shortcuts.
+ * @return mapping of action names to key sequences.
+ */
+QMap<QString, QKeySequence> KdeMainWindow::shortcutsMap() const
+{
+  QMap<QString, QKeySequence> map;
+  if (KActionCollection* collection = actionCollection()) {
+    const auto actions = collection->actions();
+    for (QAction* action : actions) {
+      if (action) {
+        QString name = action->objectName();
+        if (!name.isEmpty()) {
+          map.insert(name, action->shortcut());
+        }
+      }
+    }
+  }
+  return map;
+}
+
 /**
  * Add directory to recent files list.
  *
@@ -565,9 +613,12 @@ void KdeMainWindow::slotFileOpenRecentUrl(const QUrl& url)
  */
 void KdeMainWindow::slotSettingsShortcuts()
 {
-  KShortcutsDialog::configure(
-    actionCollection(),
-    KShortcutsEditor::LetterShortcutsDisallowed, this);
+  if (KShortcutsDialog::configure(
+        actionCollection(),
+        KShortcutsEditor::LetterShortcutsAllowed, this) ==
+      QDialog::Accepted) {
+    impl()->applyChangedShortcuts();
+  }
 }
 
 /**
