@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 07 Apr 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,18 +26,13 @@
 
 #include "kdesettings.h"
 #include <QtConfig>
-#if QT_VERSION >= 0x050000
 #include <KConfig>
 #include <KConfigGroup>
-#else
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#endif
 
 /**
  * Constructor.
  */
-KdeSettings::KdeSettings(KConfig* config) : m_config(config), m_group(0)
+KdeSettings::KdeSettings(KConfig* config) : m_config(config)
 {
   migrateOldSettings();
 }
@@ -47,7 +42,7 @@ KdeSettings::KdeSettings(KConfig* config) : m_config(config), m_group(0)
  */
 KdeSettings::~KdeSettings()
 {
-  delete m_group;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -56,8 +51,7 @@ KdeSettings::~KdeSettings()
  */
 void KdeSettings::beginGroup(const QString& prefix)
 {
-  delete m_group;
-  m_group = new KConfigGroup(m_config, prefix);
+  m_group.reset(new KConfigGroup(m_config, prefix));
 }
 
 /**
@@ -65,8 +59,7 @@ void KdeSettings::beginGroup(const QString& prefix)
  */
 void KdeSettings::endGroup()
 {
-  delete m_group;
-  m_group = 0;
+  m_group.reset();
 }
 
 /**
