@@ -30,6 +30,7 @@
 #include <QLocale>
 #include <QTranslator>
 #include <QDir>
+#include <QSettings>
 #include "fileconfig.h"
 #include "loadtranslation.h"
 #include "kid3mainwindow.h"
@@ -58,8 +59,6 @@ int main(int argc, char* argv[])
   Kid3QtApplication app(argc, argv);
   QCoreApplication::setApplicationName(QLatin1String("Kid3"));
 
-  Utils::loadTranslation();
-
 #ifdef Q_OS_MAC
   QDir dir(QApplication::applicationDirPath());
   dir.cdUp();
@@ -74,6 +73,18 @@ int main(int argc, char* argv[])
             QCoreApplication::applicationDirPath().toLatin1() + "/kid3.ini");
   }
 
+  // The Language setting has to be read bypassing the regular
+  // configuration object because the language must be set before
+  // the application is created.
+  QByteArray configPath = qgetenv("KID3_CONFIG_FILE");
+  auto configuredLanguage = configPath.isNull()
+      ? QSettings(QSettings::UserScope, QLatin1String("Kid3"),
+                  QLatin1String("Kid3"))
+        .value(QLatin1String("MainWindow/Language")).toString()
+      : QSettings(QFile::decodeName(configPath), QSettings::IniFormat)
+        .value(QLatin1String("MainWindow/Language")).toString();
+  Utils::loadTranslation(configuredLanguage);
+
   IPlatformTools* platformTools = new PlatformTools;
   auto kid3App = new Kid3Application(platformTools);
 #ifdef HAVE_QTDBUS
@@ -85,12 +96,12 @@ int main(int argc, char* argv[])
                    kid3App, &Kid3Application::openDrop);
   kid3->show();
   if (args.size() > 1) {
-    kid3->confirmedOpenDirectory(args.mid(1));
+    kid3App->openDirectory(args.mid(1));
   } else if ((FileConfig::instance().loadLastOpenedFile() ||
               app.isSessionRestored()) &&
              !FileConfig::instance().lastOpenedFile().isEmpty()) {
-    kid3->confirmedOpenDirectory(QStringList()
-                                 << FileConfig::instance().lastOpenedFile());
+    kid3App->openDirectory(QStringList()
+                           << FileConfig::instance().lastOpenedFile());
   }
   int rc = QApplication::exec();
   delete kid3App;
