@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2017  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,24 +27,25 @@
 #include "formatconfig.h"
 #include "config.h"
 #include <QString>
+#include <QRegularExpression>
 #include <QLocale>
 #include <QCoreApplication>
 #include "generalconfig.h"
+#include "isettings.h"
 #include "frame.h"
 
 /**
  * Constructor.
  */
-FormatConfig::FormatConfig(const QString& grp) :
-  GeneralConfig(grp),
-  m_caseConversion(AllFirstLettersUppercase),
-  m_locale(0),
-  m_maximumLength(255),
-  m_enableMaximumLength(false),
-  m_filenameFormatter(false),
-  m_formatWhileEditing(false),
-  m_strRepEnabled(false),
-  m_enableValidation(true)
+FormatConfig::FormatConfig(const QString& grp)
+  : GeneralConfig(grp),
+    m_caseConversion(AllFirstLettersUppercase),
+    m_maximumLength(255),
+    m_enableMaximumLength(false),
+    m_filenameFormatter(false),
+    m_formatWhileEditing(false),
+    m_strRepEnabled(false),
+    m_enableValidation(true)
 {
   m_strRepMap.clear();
 }
@@ -54,7 +55,7 @@ FormatConfig::FormatConfig(const QString& grp) :
  */
 FormatConfig::~FormatConfig()
 {
-  delete m_locale;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -67,79 +68,80 @@ void FormatConfig::setAsFilenameFormatter()
   m_filenameFormatter = true;
   m_caseConversion = NoChanges;
   m_localeName = QString();
-  delete m_locale;
-  m_locale = 0;
+  m_locale.reset();
   m_strRepEnabled = true;
-  m_strRepMap[QLatin1String("/")] = QLatin1Char('-');
-  m_strRepMap[QLatin1String(":")] = QLatin1Char('-');
-  m_strRepMap[QLatin1String(".")] = QLatin1String("");
-  m_strRepMap[QLatin1String("?")] = QLatin1String("");
-  m_strRepMap[QLatin1String("*")] = QLatin1String("");
-  m_strRepMap[QLatin1String("\"")] = QLatin1String("''");
-  m_strRepMap[QLatin1String("<")] = QLatin1Char('-');
-  m_strRepMap[QLatin1String(">")] = QLatin1Char('-');
-  m_strRepMap[QLatin1String("|")] = QLatin1Char('-');
-  m_strRepMap[QChar(0xe4)] = QLatin1String("ae");
-  m_strRepMap[QChar(0xf6)] = QLatin1String("oe");
-  m_strRepMap[QChar(0xfc)] = QLatin1String("ue");
-  m_strRepMap[QChar(0xc4)] = QLatin1String("Ae");
-  m_strRepMap[QChar(0xd6)] = QLatin1String("Oe");
-  m_strRepMap[QChar(0xdc)] = QLatin1String("Ue");
-  m_strRepMap[QChar(0xdf)] = QLatin1String("ss");
-  m_strRepMap[QChar(0xc0)] = QLatin1Char('A');
-  m_strRepMap[QChar(0xc1)] = QLatin1Char('A');
-  m_strRepMap[QChar(0xc2)] = QLatin1Char('A');
-  m_strRepMap[QChar(0xc3)] = QLatin1Char('A');
-  m_strRepMap[QChar(0xc5)] = QLatin1Char('A');
-  m_strRepMap[QChar(0xc6)] = QLatin1String("AE");
-  m_strRepMap[QChar(0xc7)] = QLatin1Char('C');
-  m_strRepMap[QChar(0xc8)] = QLatin1Char('E');
-  m_strRepMap[QChar(0xc9)] = QLatin1Char('E');
-  m_strRepMap[QChar(0xca)] = QLatin1Char('E');
-  m_strRepMap[QChar(0xcb)] = QLatin1Char('E');
-  m_strRepMap[QChar(0xcc)] = QLatin1Char('I');
-  m_strRepMap[QChar(0xcd)] = QLatin1Char('I');
-  m_strRepMap[QChar(0xce)] = QLatin1Char('I');
-  m_strRepMap[QChar(0xcf)] = QLatin1Char('I');
-  m_strRepMap[QChar(0xd0)] = QLatin1Char('D');
-  m_strRepMap[QChar(0xd1)] = QLatin1Char('N');
-  m_strRepMap[QChar(0xd2)] = QLatin1Char('O');
-  m_strRepMap[QChar(0xd3)] = QLatin1Char('O');
-  m_strRepMap[QChar(0xd4)] = QLatin1Char('O');
-  m_strRepMap[QChar(0xd5)] = QLatin1Char('O');
-  m_strRepMap[QChar(0xd7)] = QLatin1Char('x');
-  m_strRepMap[QChar(0xd8)] = QLatin1Char('O');
-  m_strRepMap[QChar(0xd9)] = QLatin1Char('U');
-  m_strRepMap[QChar(0xda)] = QLatin1Char('U');
-  m_strRepMap[QChar(0xdb)] = QLatin1Char('U');
-  m_strRepMap[QChar(0xdd)] = QLatin1Char('Y');
-  m_strRepMap[QChar(0xe0)] = QLatin1Char('a');
-  m_strRepMap[QChar(0xe1)] = QLatin1Char('a');
-  m_strRepMap[QChar(0xe2)] = QLatin1Char('a');
-  m_strRepMap[QChar(0xe3)] = QLatin1Char('a');
-  m_strRepMap[QChar(0xe5)] = QLatin1Char('a');
-  m_strRepMap[QChar(0xe6)] = QLatin1String("ae");
-  m_strRepMap[QChar(0xe7)] = QLatin1Char('c');
-  m_strRepMap[QChar(0xe8)] = QLatin1Char('e');
-  m_strRepMap[QChar(0xe9)] = QLatin1Char('e');
-  m_strRepMap[QChar(0xea)] = QLatin1Char('e');
-  m_strRepMap[QChar(0xeb)] = QLatin1Char('e');
-  m_strRepMap[QChar(0xec)] = QLatin1Char('i');
-  m_strRepMap[QChar(0xed)] = QLatin1Char('i');
-  m_strRepMap[QChar(0xee)] = QLatin1Char('i');
-  m_strRepMap[QChar(0xef)] = QLatin1Char('i');
-  m_strRepMap[QChar(0xf0)] = QLatin1Char('d');
-  m_strRepMap[QChar(0xf1)] = QLatin1Char('n');
-  m_strRepMap[QChar(0xf2)] = QLatin1Char('o');
-  m_strRepMap[QChar(0xf3)] = QLatin1Char('o');
-  m_strRepMap[QChar(0xf4)] = QLatin1Char('o');
-  m_strRepMap[QChar(0xf5)] = QLatin1Char('o');
-  m_strRepMap[QChar(0xf8)] = QLatin1Char('o');
-  m_strRepMap[QChar(0xf9)] = QLatin1Char('u');
-  m_strRepMap[QChar(0xfa)] = QLatin1Char('u');
-  m_strRepMap[QChar(0xfb)] = QLatin1Char('u');
-  m_strRepMap[QChar(0xfd)] = QLatin1Char('y');
-  m_strRepMap[QChar(0xff)] = QLatin1Char('y');
+  m_strRepMap.append({
+    {QLatin1String("/"), QLatin1String("-")},
+    {QLatin1String(":"), QLatin1String("-")},
+    {QLatin1String("."), QLatin1String("")},
+    {QLatin1String("?"), QLatin1String("")},
+    {QLatin1String("*"), QLatin1String("")},
+    {QLatin1String("\""), QLatin1String("''")},
+    {QLatin1String("<"), QLatin1String("-")},
+    {QLatin1String(">"), QLatin1String("-")},
+    {QLatin1String("|"), QLatin1String("-")},
+    {QChar(0xe4), QLatin1String("ae")},
+    {QChar(0xf6), QLatin1String("oe")},
+    {QChar(0xfc), QLatin1String("ue")},
+    {QChar(0xc4), QLatin1String("Ae")},
+    {QChar(0xd6), QLatin1String("Oe")},
+    {QChar(0xdc), QLatin1String("Ue")},
+    {QChar(0xdf), QLatin1String("ss")},
+    {QChar(0xc0), QLatin1String("A")},
+    {QChar(0xc1), QLatin1String("A")},
+    {QChar(0xc2), QLatin1String("A")},
+    {QChar(0xc3), QLatin1String("A")},
+    {QChar(0xc5), QLatin1String("A")},
+    {QChar(0xc6), QLatin1String("AE")},
+    {QChar(0xc7), QLatin1String("C")},
+    {QChar(0xc8), QLatin1String("E")},
+    {QChar(0xc9), QLatin1String("E")},
+    {QChar(0xca), QLatin1String("E")},
+    {QChar(0xcb), QLatin1String("E")},
+    {QChar(0xcc), QLatin1String("I")},
+    {QChar(0xcd), QLatin1String("I")},
+    {QChar(0xce), QLatin1String("I")},
+    {QChar(0xcf), QLatin1String("I")},
+    {QChar(0xd0), QLatin1String("D")},
+    {QChar(0xd1), QLatin1String("N")},
+    {QChar(0xd2), QLatin1String("O")},
+    {QChar(0xd3), QLatin1String("O")},
+    {QChar(0xd4), QLatin1String("O")},
+    {QChar(0xd5), QLatin1String("O")},
+    {QChar(0xd7), QLatin1String("x")},
+    {QChar(0xd8), QLatin1String("O")},
+    {QChar(0xd9), QLatin1String("U")},
+    {QChar(0xda), QLatin1String("U")},
+    {QChar(0xdb), QLatin1String("U")},
+    {QChar(0xdd), QLatin1String("Y")},
+    {QChar(0xe0), QLatin1String("a")},
+    {QChar(0xe1), QLatin1String("a")},
+    {QChar(0xe2), QLatin1String("a")},
+    {QChar(0xe3), QLatin1String("a")},
+    {QChar(0xe5), QLatin1String("a")},
+    {QChar(0xe6), QLatin1String("ae")},
+    {QChar(0xe7), QLatin1String("c")},
+    {QChar(0xe8), QLatin1String("e")},
+    {QChar(0xe9), QLatin1String("e")},
+    {QChar(0xea), QLatin1String("e")},
+    {QChar(0xeb), QLatin1String("e")},
+    {QChar(0xec), QLatin1String("i")},
+    {QChar(0xed), QLatin1String("i")},
+    {QChar(0xee), QLatin1String("i")},
+    {QChar(0xef), QLatin1String("i")},
+    {QChar(0xf0), QLatin1String("d")},
+    {QChar(0xf1), QLatin1String("n")},
+    {QChar(0xf2), QLatin1String("o")},
+    {QChar(0xf3), QLatin1String("o")},
+    {QChar(0xf4), QLatin1String("o")},
+    {QChar(0xf5), QLatin1String("o")},
+    {QChar(0xf8), QLatin1String("o")},
+    {QChar(0xf9), QLatin1String("u")},
+    {QChar(0xfa), QLatin1String("u")},
+    {QChar(0xfb), QLatin1String("u")},
+    {QChar(0xfd), QLatin1String("y")},
+    {QChar(0xff), QLatin1String("y")}
+  });
 }
 
 /**
@@ -217,9 +219,17 @@ void FormatConfig::formatString(QString& str) const
     }
   }
   if (m_strRepEnabled) {
-    QMap<QString, QString>::ConstIterator it;
-    for (it = m_strRepMap.begin(); it != m_strRepMap.end(); ++it) {
-      str.replace(it.key(), *it);
+    for (auto it = m_strRepMap.constBegin(); it != m_strRepMap.constEnd(); ++it) {
+      QString before = it->first;
+      QString after = it->second;
+      if (before.length() > 1 &&
+          before.startsWith(QLatin1Char('/')) &&
+          before.endsWith(QLatin1Char('/'))) {
+        QRegularExpression re(before.mid(1, before.length() - 2));
+        str.replace(re, after);
+      } else {
+        str.replace(before, after);
+      }
     }
   }
   str = joinFileName(str, ext);
@@ -259,20 +269,16 @@ QString FormatConfig::joinFileName(const QString& baseName,
 /** Returns a lowercase copy of @a str. */
 QString FormatConfig::toLower(const QString& str) const
 {
-#if QT_VERSION >= 0x040800
   if (m_locale)
     return m_locale->toLower(str);
-#endif
   return str.toLower();
 }
 
 /** Returns an uppercase copy of @a str. */
 QString FormatConfig::toUpper(const QString& str) const
 {
-#if QT_VERSION >= 0x040800
   if (m_locale)
     return m_locale->toUpper(str);
-#endif
   return str.toUpper();
 }
 
@@ -283,10 +289,8 @@ QString FormatConfig::toUpper(const QString& str) const
  */
 void FormatConfig::formatFrames(FrameCollection& frames) const
 {
-  for (FrameCollection::iterator it = frames.begin();
-       it != frames.end();
-       ++it) {
-    Frame& frame = const_cast<Frame&>(*it);
+  for (auto it = frames.cbegin(); it != frames.cend(); ++it) {
+    auto& frame = const_cast<Frame&>(*it);
     if (frame.getType() != Frame::FT_Genre) {
       QString value(frame.getValue());
       if (!value.isEmpty()) {
@@ -324,8 +328,13 @@ void FormatConfig::writeToConfig(ISettings* config) const
   config->setValue(QLatin1String("EnableValidation"), QVariant(m_enableValidation));
   config->setValue(QLatin1String("EnableMaximumLength"), QVariant(m_enableMaximumLength));
   config->setValue(QLatin1String("MaximumLength"), QVariant(m_maximumLength));
-  config->setValue(QLatin1String("StrRepMapKeys"), QVariant(m_strRepMap.keys()));
-  config->setValue(QLatin1String("StrRepMapValues"), QVariant(m_strRepMap.values()));
+  QStringList keys, values;
+  for (auto it = m_strRepMap.constBegin(); it != m_strRepMap.constEnd(); ++it) {
+    keys.append(it->first);
+    values.append(it->second);
+  }
+  config->setValue(QLatin1String("StrRepMapKeys"), QVariant(keys));
+  config->setValue(QLatin1String("StrRepMapValues"), QVariant(values));
   config->endGroup();
 }
 
@@ -337,25 +346,31 @@ void FormatConfig::writeToConfig(ISettings* config) const
 void FormatConfig::readFromConfig(ISettings* config)
 {
   config->beginGroup(m_group);
-  m_formatWhileEditing = config->value(QLatin1String("FormatWhileEditing"), m_formatWhileEditing).toBool();
-  m_caseConversion = (CaseConversion)config->value(QLatin1String("CaseConversion"),
-                                                   (int)m_caseConversion).toInt();
-  m_localeName = config->value(QLatin1String("LocaleName"), m_localeName).toString();
-  m_strRepEnabled = config->value(QLatin1String("StrRepEnabled"), m_strRepEnabled).toBool();
-  m_enableValidation = config->value(QLatin1String("EnableValidation"), m_enableValidation).toBool();
-  m_enableMaximumLength = config->value(QLatin1String("EnableMaximumLength"), m_enableMaximumLength).toBool();
-  m_maximumLength = config->value(QLatin1String("MaximumLength"), m_maximumLength).toInt();
+  m_formatWhileEditing = config->value(QLatin1String("FormatWhileEditing"),
+                                       m_formatWhileEditing).toBool();
+  m_caseConversion = static_cast<CaseConversion>(
+        config->value(QLatin1String("CaseConversion"),
+                      static_cast<int>(m_caseConversion)).toInt());
+  m_localeName = config->value(QLatin1String("LocaleName"),
+                               m_localeName).toString();
+  m_strRepEnabled = config->value(QLatin1String("StrRepEnabled"),
+                                  m_strRepEnabled).toBool();
+  m_enableValidation = config->value(QLatin1String("EnableValidation"),
+                                     m_enableValidation).toBool();
+  m_enableMaximumLength = config->value(QLatin1String("EnableMaximumLength"),
+                                        m_enableMaximumLength).toBool();
+  m_maximumLength = config->value(QLatin1String("MaximumLength"),
+                                  m_maximumLength).toInt();
   QStringList keys = config->value(QLatin1String("StrRepMapKeys"),
                                    QStringList()).toStringList();
   QStringList values = config->value(QLatin1String("StrRepMapValues"),
                                      QStringList()).toStringList();
   if (!keys.empty() && !values.empty()) {
-    QStringList::Iterator itk, itv;
     m_strRepMap.clear();
-    for (itk = keys.begin(), itv = values.begin();
-       itk != keys.end() && itv != values.end();
-       ++itk, ++itv) {
-      m_strRepMap[*itk] = *itv;
+    for (auto itk = keys.constBegin(), itv = values.constBegin();
+         itk != keys.constEnd() && itv != values.constEnd();
+         ++itk, ++itv) {
+      m_strRepMap.append({*itk, *itv});
     }
   }
   config->endGroup();
@@ -369,8 +384,7 @@ void FormatConfig::setLocaleName(const QString& localeName)
 {
   if (localeName != m_localeName) {
     m_localeName = localeName;
-    delete m_locale;
-    m_locale = new QLocale(m_localeName);
+    m_locale.reset(new QLocale(m_localeName));
     emit localeNameChanged(m_localeName);
   }
 }
@@ -399,7 +413,7 @@ void FormatConfig::setMaximumLength(int maximumLength)
   }
 }
 
-void FormatConfig::setStrRepMap(const QMap<QString, QString>& strRepMap)
+void FormatConfig::setStrRepMap(const QList<QPair<QString, QString>>& strRepMap)
 {
   if (m_strRepMap != strRepMap) {
     m_strRepMap = strRepMap;
@@ -407,24 +421,27 @@ void FormatConfig::setStrRepMap(const QMap<QString, QString>& strRepMap)
   }
 }
 
-QVariantMap FormatConfig::strRepVariantMap() const
+QStringList FormatConfig::strRepStringList() const
 {
-  QVariantMap map;
-  for (QMap<QString, QString>::const_iterator it = m_strRepMap.constBegin();
+  QStringList lst;
+  for (auto it = m_strRepMap.constBegin();
        it != m_strRepMap.constEnd();
        ++it) {
-    map.insert(it.key(), it.value());
+    lst.append(it->first);
+    lst.append(it->second);
   }
-  return map;
+  return lst;
 }
 
-void FormatConfig::setStrRepVariantMap(const QVariantMap& map)
+void FormatConfig::setStrRepStringList(const QStringList& lst)
 {
-  QMap<QString, QString> strRepMap;
-  for (QVariantMap::const_iterator it = map.constBegin();
-       it != map.constEnd();
-       ++it) {
-    strRepMap.insert(it.key(), it.value().toString());
+  QList<QPair<QString, QString>> strRepMap;
+  auto it = lst.constBegin();
+  while (it != lst.constEnd()) {
+    QString key = *it++;
+    if (it != lst.constEnd()) {
+      strRepMap.append({key, *it++});
+    }
   }
   setStrRepMap(strRepMap);
 }
@@ -478,11 +495,7 @@ QStringList FormatConfig::getCaseConversionNames()
  */
 QStringList FormatConfig::getLocaleNames()
 {
-  return QStringList() << tr("None")
-#if QT_VERSION >= 0x040800
-                       << QLocale().uiLanguages()
-#endif
-                          ;
+  return QStringList() << tr("None") << QLocale().uiLanguages();
 }
 
 
@@ -491,34 +504,20 @@ int FilenameFormatConfig::s_index = -1;
 /**
  * Constructor.
  */
-FilenameFormatConfig::FilenameFormatConfig() :
-  StoredConfig<FilenameFormatConfig, FormatConfig>(
-    QLatin1String("FilenameFormat"))
+FilenameFormatConfig::FilenameFormatConfig()
+  : StoredConfig<FilenameFormatConfig, FormatConfig>(
+      QLatin1String("FilenameFormat"))
 {
   setAsFilenameFormatter();
 }
 
-/**
- * Destructor.
- */
-FilenameFormatConfig::~FilenameFormatConfig()
-{
-}
-
 
 int TagFormatConfig::s_index = -1;
 
 /**
  * Constructor.
  */
-TagFormatConfig::TagFormatConfig() :
-  StoredConfig<TagFormatConfig, FormatConfig>(QLatin1String("TagFormat"))
-{
-}
-
-/**
- * Destructor.
- */
-TagFormatConfig::~TagFormatConfig()
+TagFormatConfig::TagFormatConfig()
+  : StoredConfig<TagFormatConfig, FormatConfig>(QLatin1String("TagFormat"))
 {
 }
