@@ -29,6 +29,7 @@
 #include <QVector>
 #include "taggedfile.h"
 #include "frame.h"
+#include "isettings.h"
 
 namespace {
 
@@ -150,9 +151,7 @@ int StarRatingMapping::starCountToRating(int starCount, const QString& type) con
 const QVector<int>& StarRatingMapping::valuesForType(const QString& type) const
 {
   // First search in the maps for the given type.
-  for (QList<QPair<QString, QVector<int> > >::const_iterator it = m_maps.constBegin();
-       it != m_maps.constEnd();
-       ++it) {
+  for (auto it = m_maps.constBegin(); it != m_maps.constEnd(); ++it) {
     if (type == it->first) {
       return it->second;
     }
@@ -164,13 +163,9 @@ const QVector<int>& StarRatingMapping::valuesForType(const QString& type) const
 QStringList StarRatingMapping::toStringList() const
 {
   QStringList strs;
-  for (QList<QPair<QString, QVector<int> > >::const_iterator it = m_maps.constBegin();
-       it != m_maps.constEnd();
-       ++it) {
+  for (auto it = m_maps.constBegin(); it != m_maps.constEnd(); ++it) {
     QString str = it->first;
-    for (QVector<int>::const_iterator sit = it->second.constBegin();
-         sit != it->second.constEnd();
-         ++sit) {
+    for (auto sit = it->second.constBegin(); sit != it->second.constEnd(); ++sit) {
       str += QLatin1Char(',');
       str += QString::number(*sit);
     }
@@ -182,14 +177,13 @@ QStringList StarRatingMapping::toStringList() const
 void StarRatingMapping::fromStringList(const QStringList& strs)
 {
   QList<QPair<QString, QVector<int> > > maps;
-  for (QStringList::const_iterator it = strs.constBegin();
-       it != strs.constEnd();
-       ++it) {
+  QVector<int> values;
+  for (auto it = strs.constBegin(); it != strs.constEnd(); ++it) {
     QStringList parts = it->split(QLatin1Char(','));
     const int numParts = parts.size();
     if (numParts >= MAX_STAR_COUNT + 1) {
       bool ok = false;
-      QVector<int> values;
+      values.resize(0);
       int lastValue = -1;
       for (int i = numParts - MAX_STAR_COUNT; i < numParts; ++i) {
         int value = parts.at(i).toInt(&ok);
@@ -215,9 +209,7 @@ void StarRatingMapping::fromStringList(const QStringList& strs)
 
 QString StarRatingMapping::defaultPopmEmail() const
 {
-  for (QList<QPair<QString, QVector<int> > >::const_iterator it = m_maps.constBegin();
-       it != m_maps.constEnd();
-       ++it) {
+  for (auto it = m_maps.constBegin(); it != m_maps.constEnd(); ++it) {
     QString type = it->first;
     if (type.startsWith(QLatin1String("POPM"))) {
       return type.length() > 4 && type.at(4) == QLatin1Char('.')
@@ -233,26 +225,26 @@ int TagConfig::s_index = -1;
 /**
  * Constructor.
  */
-TagConfig::TagConfig() :
-  StoredConfig<TagConfig>(QLatin1String("Tags")),
-  m_starRatingMapping(new StarRatingMapping),
-  m_commentName(QString::fromLatin1(defaultCommentName)),
-  m_riffTrackName(QString::fromLatin1(defaultRiffTrackName)),
-  m_pictureNameItem(VP_METADATA_BLOCK_PICTURE),
-  m_id3v2Version(ID3v2_3_0),
-  m_textEncodingV1(QLatin1String("ISO-8859-1")),
-  m_textEncoding(TE_ISO8859_1),
-  m_quickAccessFrames(FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES),
-  m_trackNumberDigits(1),
-  m_taggedFileFeatures(0),
-  m_maximumPictureSize(131072),
-  m_markOversizedPictures(false),
-  m_markStandardViolations(true),
-  m_onlyCustomGenres(false),
-  m_markTruncations(true),
-  m_enableTotalNumberOfTracks(false),
-  m_genreNotNumeric(true),
-  m_lowercaseId3RiffChunk(false)
+TagConfig::TagConfig()
+  : StoredConfig<TagConfig>(QLatin1String("Tags")),
+    m_starRatingMapping(new StarRatingMapping),
+    m_commentName(QString::fromLatin1(defaultCommentName)),
+    m_riffTrackName(QString::fromLatin1(defaultRiffTrackName)),
+    m_pictureNameItem(VP_METADATA_BLOCK_PICTURE),
+    m_id3v2Version(ID3v2_3_0),
+    m_textEncodingV1(QLatin1String("ISO-8859-1")),
+    m_textEncoding(TE_ISO8859_1),
+    m_quickAccessFrames(FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES),
+    m_trackNumberDigits(1),
+    m_taggedFileFeatures(0),
+    m_maximumPictureSize(131072),
+    m_markOversizedPictures(false),
+    m_markStandardViolations(true),
+    m_onlyCustomGenres(false),
+    m_markTruncations(true),
+    m_enableTotalNumberOfTracks(false),
+    m_genreNotNumeric(true),
+    m_lowercaseId3RiffChunk(false)
 {
   m_disabledPlugins << QLatin1String("Id3libMetadata")
                     << QLatin1String("Mp4v2Metadata");
@@ -263,7 +255,7 @@ TagConfig::TagConfig() :
  */
 TagConfig::~TagConfig()
 {
-  delete m_starRatingMapping;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -274,33 +266,54 @@ TagConfig::~TagConfig()
 void TagConfig::writeToConfig(ISettings* config) const
 {
   config->beginGroup(m_group);
-  config->setValue(QLatin1String("MarkTruncations"), QVariant(m_markTruncations));
-  config->setValue(QLatin1String("MarkOversizedPictures"), QVariant(m_markOversizedPictures));
-  config->setValue(QLatin1String("MaximumPictureSize"), QVariant(m_maximumPictureSize));
-  config->setValue(QLatin1String("MarkStandardViolations"), QVariant(m_markStandardViolations));
-  config->setValue(QLatin1String("EnableTotalNumberOfTracks"), QVariant(m_enableTotalNumberOfTracks));
-  config->setValue(QLatin1String("GenreNotNumeric"), QVariant(m_genreNotNumeric));
-  config->setValue(QLatin1String("LowercaseId3RiffChunk"), QVariant(m_lowercaseId3RiffChunk));
-  config->setValue(QLatin1String("CommentName"), QVariant(m_commentName));
-  config->setValue(QLatin1String("PictureNameItem"), QVariant(m_pictureNameItem));
-  config->setValue(QLatin1String("RiffTrackName"), QVariant(m_riffTrackName));
-  config->setValue(QLatin1String("CustomGenres"), QVariant(m_customGenres));
-  config->setValue(QLatin1String("ID3v2Version"), QVariant(m_id3v2Version));
-  config->setValue(QLatin1String("TextEncodingV1"), QVariant(m_textEncodingV1));
-  config->setValue(QLatin1String("TextEncoding"), QVariant(m_textEncoding));
+  config->setValue(QLatin1String("MarkTruncations"),
+                   QVariant(m_markTruncations));
+  config->setValue(QLatin1String("MarkOversizedPictures"),
+                   QVariant(m_markOversizedPictures));
+  config->setValue(QLatin1String("MaximumPictureSize"),
+                   QVariant(m_maximumPictureSize));
+  config->setValue(QLatin1String("MarkStandardViolations"),
+                   QVariant(m_markStandardViolations));
+  config->setValue(QLatin1String("EnableTotalNumberOfTracks"),
+                   QVariant(m_enableTotalNumberOfTracks));
+  config->setValue(QLatin1String("GenreNotNumeric"),
+                   QVariant(m_genreNotNumeric));
+  config->setValue(QLatin1String("LowercaseId3RiffChunk"),
+                   QVariant(m_lowercaseId3RiffChunk));
+  config->setValue(QLatin1String("CommentName"),
+                   QVariant(m_commentName));
+  config->setValue(QLatin1String("PictureNameItem"),
+                   QVariant(m_pictureNameItem));
+  config->setValue(QLatin1String("RiffTrackName"),
+                   QVariant(m_riffTrackName));
+  config->setValue(QLatin1String("CustomGenres"),
+                   QVariant(m_customGenres));
+  config->setValue(QLatin1String("ID3v2Version"),
+                   QVariant(m_id3v2Version));
+  config->setValue(QLatin1String("TextEncodingV1"),
+                   QVariant(m_textEncodingV1));
+  config->setValue(QLatin1String("TextEncoding"),
+                   QVariant(m_textEncoding));
 #ifdef Q_OS_MAC
   // Convince Mac OS X to store a 64-bit value.
-  config->setValue(QLatin1String("QuickAccessFrames"), QVariant(m_quickAccessFrames | (Q_UINT64_C(1) << 63)));
+  config->setValue(QLatin1String("QuickAccessFrames"),
+                   QVariant(m_quickAccessFrames | (Q_UINT64_C(1) << 63)));
 #else
-  config->setValue(QLatin1String("QuickAccessFrames"), QVariant(m_quickAccessFrames));
+  config->setValue(QLatin1String("QuickAccessFrames"),
+                   QVariant(m_quickAccessFrames));
 #endif
   config->setValue(QLatin1String("QuickAccessFrameOrder"),
                    QVariant(intListToStringList(m_quickAccessFrameOrder)));
-  config->setValue(QLatin1String("TrackNumberDigits"), QVariant(m_trackNumberDigits));
-  config->setValue(QLatin1String("OnlyCustomGenres"), QVariant(m_onlyCustomGenres));
-  config->setValue(QLatin1String("PluginOrder"), QVariant(m_pluginOrder));
-  config->setValue(QLatin1String("DisabledPlugins"), QVariant(m_disabledPlugins));
-  config->setValue(QLatin1String("StarRatingMapping"), QVariant(m_starRatingMapping->toStringList()));
+  config->setValue(QLatin1String("TrackNumberDigits"),
+                   QVariant(m_trackNumberDigits));
+  config->setValue(QLatin1String("OnlyCustomGenres"),
+                   QVariant(m_onlyCustomGenres));
+  config->setValue(QLatin1String("PluginOrder"),
+                   QVariant(m_pluginOrder));
+  config->setValue(QLatin1String("DisabledPlugins"),
+                   QVariant(m_disabledPlugins));
+  config->setValue(QLatin1String("StarRatingMapping"),
+                   QVariant(m_starRatingMapping->toStringList()));
   config->endGroup();
 }
 
@@ -312,36 +325,58 @@ void TagConfig::writeToConfig(ISettings* config) const
 void TagConfig::readFromConfig(ISettings* config)
 {
   config->beginGroup(m_group);
-  m_markTruncations = config->value(QLatin1String("MarkTruncations"), m_markTruncations).toBool();
-  m_markOversizedPictures = config->value(QLatin1String("MarkOversizedPictures"), m_markOversizedPictures).toBool();
-  m_maximumPictureSize = config->value(QLatin1String("MaximumPictureSize"), m_maximumPictureSize).toInt();
-  m_markStandardViolations = config->value(QLatin1String("MarkStandardViolations"), m_markStandardViolations).toBool();
-  m_enableTotalNumberOfTracks = config->value(QLatin1String("EnableTotalNumberOfTracks"), m_enableTotalNumberOfTracks).toBool();
-  m_genreNotNumeric = config->value(QLatin1String("GenreNotNumeric"), m_genreNotNumeric).toBool();
-  m_lowercaseId3RiffChunk = config->value(QLatin1String("LowercaseId3RiffChunk"), m_lowercaseId3RiffChunk).toBool();
-  m_commentName = config->value(QLatin1String("CommentName"), QString::fromLatin1(defaultCommentName)).toString();
-  m_pictureNameItem = config->value(QLatin1String("PictureNameItem"), VP_METADATA_BLOCK_PICTURE).toInt();
-  m_riffTrackName = config->value(QLatin1String("RiffTrackName"), QString::fromLatin1(defaultRiffTrackName)).toString();
+  m_markTruncations = config->value(QLatin1String("MarkTruncations"),
+                                    m_markTruncations).toBool();
+  m_markOversizedPictures = config->value(QLatin1String("MarkOversizedPictures"),
+                                          m_markOversizedPictures).toBool();
+  m_maximumPictureSize = config->value(QLatin1String("MaximumPictureSize"),
+                                       m_maximumPictureSize).toInt();
+  m_markStandardViolations =
+      config->value(QLatin1String("MarkStandardViolations"),
+                    m_markStandardViolations).toBool();
+  m_enableTotalNumberOfTracks =
+      config->value(QLatin1String("EnableTotalNumberOfTracks"),
+                    m_enableTotalNumberOfTracks).toBool();
+  m_genreNotNumeric = config->value(QLatin1String("GenreNotNumeric"),
+                                    m_genreNotNumeric).toBool();
+  m_lowercaseId3RiffChunk = config->value(QLatin1String("LowercaseId3RiffChunk"),
+                                          m_lowercaseId3RiffChunk).toBool();
+  m_commentName =
+      config->value(QLatin1String("CommentName"),
+                    QString::fromLatin1(defaultCommentName)).toString();
+  m_pictureNameItem = config->value(QLatin1String("PictureNameItem"),
+                                    VP_METADATA_BLOCK_PICTURE).toInt();
+  m_riffTrackName =
+      config->value(QLatin1String("RiffTrackName"),
+                    QString::fromLatin1(defaultRiffTrackName)).toString();
   m_customGenres = config->value(QLatin1String("CustomGenres"),
                                  m_customGenres).toStringList();
-  m_id3v2Version = config->value(QLatin1String("ID3v2Version"), ID3v2_3_0).toInt();
-  m_textEncodingV1 = config->value(QLatin1String("TextEncodingV1"), QLatin1String("ISO-8859-1")).toString();
-  m_textEncoding = config->value(QLatin1String("TextEncoding"), TE_ISO8859_1).toInt();
-  m_quickAccessFrames = config->value(QLatin1String("QuickAccessFrames"),
-                                     FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES).toULongLong();
+  m_id3v2Version = config->value(QLatin1String("ID3v2Version"),
+                                 ID3v2_3_0).toInt();
+  m_textEncodingV1 = config->value(QLatin1String("TextEncodingV1"),
+                                   QLatin1String("ISO-8859-1")).toString();
+  m_textEncoding = config->value(QLatin1String("TextEncoding"),
+                                 TE_ISO8859_1).toInt();
+  m_quickAccessFrames =
+      config->value(QLatin1String("QuickAccessFrames"),
+                    FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES).toULongLong();
 #ifdef Q_OS_MAC
   m_quickAccessFrames &= ~(Q_UINT64_C(1) << 63);
 #endif
   m_quickAccessFrameOrder = stringListToIntList(
-        config->value(QLatin1String("QuickAccessFrameOrder"), QStringList()).
-        toStringList());
-  m_trackNumberDigits = config->value(QLatin1String("TrackNumberDigits"), 1).toInt();
-  m_onlyCustomGenres = config->value(QLatin1String("OnlyCustomGenres"), m_onlyCustomGenres).toBool();
+        config->value(QLatin1String("QuickAccessFrameOrder"), QStringList())
+        .toStringList());
+  m_trackNumberDigits = config->value(QLatin1String("TrackNumberDigits"),
+                                      1).toInt();
+  m_onlyCustomGenres = config->value(QLatin1String("OnlyCustomGenres"),
+                                     m_onlyCustomGenres).toBool();
   m_pluginOrder = config->value(QLatin1String("PluginOrder"),
                                  m_pluginOrder).toStringList();
   m_disabledPlugins = config->value(QLatin1String("DisabledPlugins"),
                                  m_disabledPlugins).toStringList();
-  m_starRatingMapping->fromStringList(config->value(QLatin1String("StarRatingMapping"), QStringList()).toStringList());
+  m_starRatingMapping->fromStringList(
+        config->value(QLatin1String("StarRatingMapping"),
+                      QStringList()).toStringList());
   config->endGroup();
 
   if (m_pluginOrder.isEmpty()) {
@@ -360,11 +395,11 @@ void TagConfig::setDefaultPluginOrder()
     "OggFlacMetadata",
     "Mp4v2Metadata",
     "TaglibMetadata",
-    0
+    nullptr
   };
 
   m_pluginOrder.clear();
-  for (const char* const* pn = defaultPluginOrder; *pn != 0; ++pn) {
+  for (const char* const* pn = defaultPluginOrder; *pn != nullptr; ++pn) {
     m_pluginOrder += QString::fromLatin1(*pn);
   }
 }
@@ -701,8 +736,7 @@ QStringList TagConfig::getTextEncodingNames()
  */
 QStringList TagConfig::getId3v2VersionNames()
 {
-  return QStringList() << QLatin1String("ID3v2.3.0")
-                       << QLatin1String("ID3v2.4.0");
+  return {QLatin1String("ID3v2.3.0"), QLatin1String("ID3v2.4.0")};
 }
 
 /**
@@ -710,8 +744,7 @@ QStringList TagConfig::getId3v2VersionNames()
  */
 QStringList TagConfig::getCommentNames()
 {
-  return QStringList() << QLatin1String("COMMENT")
-                       << QLatin1String("DESCRIPTION");
+  return {QLatin1String("COMMENT"), QLatin1String("DESCRIPTION")};
 }
 
 /**
@@ -719,8 +752,7 @@ QStringList TagConfig::getCommentNames()
  */
 QStringList TagConfig::getPictureNames()
 {
-  return QStringList() << QLatin1String("METADATA_BLOCK_PICTURE")
-                       << QLatin1String("COVERART");
+  return {QLatin1String("METADATA_BLOCK_PICTURE"), QLatin1String("COVERART")};
 }
 
 /**
@@ -728,7 +760,5 @@ QStringList TagConfig::getPictureNames()
  */
 QStringList TagConfig::getRiffTrackNames()
 {
-  return QStringList() << QLatin1String("IPRT")
-                       << QLatin1String("ITRK")
-                       << QLatin1String("TRCK");
+  return {QLatin1String("IPRT"), QLatin1String("ITRK"), QLatin1String("TRCK")};
 }
