@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2013  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,7 +26,6 @@
 
 #include "importclient.h"
 #include <QRegExp>
-#include <QStatusBar>
 #include <QUrl>
 
 #include "serverimporterconfig.h"
@@ -36,19 +35,12 @@
  *
  * @param netMgr  network access manager
  */
-ImportClient::ImportClient(QNetworkAccessManager* netMgr) :
-  HttpClient(netMgr), m_requestType(RT_None)
+ImportClient::ImportClient(QNetworkAccessManager* netMgr)
+  : HttpClient(netMgr), m_requestType(RT_None)
 {
   setObjectName(QLatin1String("ImportClient"));
-  connect(this, SIGNAL(bytesReceived(QByteArray)),
-          this, SLOT(requestFinished(QByteArray)));
-}
-
-/**
- * Destructor.
- */
-ImportClient::~ImportClient()
-{
+  connect(this, &HttpClient::bytesReceived,
+          this, &ImportClient::requestFinished);
 }
 
 /**
@@ -92,7 +84,8 @@ void ImportClient::requestFinished(const QByteArray& rcvStr)
  * @param cat category
  * @param id  ID
  */
-void ImportClient::getTrackList(const ServerImporterConfig* cfg, QString cat, QString id)
+void ImportClient::getTrackList(const ServerImporterConfig* cfg,
+                                const QString& cat, const QString& id)
 {
   sendTrackListQuery(cfg, cat, id);
   m_requestType = RT_Album;
