@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2011  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IMPORTCLIENT_H
-#define IMPORTCLIENT_H
+#pragma once
 
 #include "httpclient.h"
 #include "kid3api.h"
@@ -35,10 +34,8 @@ class ServerImporterConfig;
 /**
  * Client to connect to server with import data.
  */
-class KID3_CORE_EXPORT ImportClient : public HttpClient
-{
-Q_OBJECT
-
+class KID3_CORE_EXPORT ImportClient : public HttpClient {
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -50,7 +47,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ImportClient();
+  virtual ~ImportClient() override = default;
 
   /**
    * Send a query command to search on the server.
@@ -93,7 +90,8 @@ public:
    * @param cat category
    * @param id  ID
    */
-  void getTrackList(const ServerImporterConfig* cfg, QString cat, QString id);
+  void getTrackList(const ServerImporterConfig* cfg,
+                    const QString& cat, const QString& id);
 
  /**
   * Encode a query in an URL.
@@ -135,5 +133,3 @@ private:
     RT_Album
   } m_requestType;
 };
-
-#endif
