@@ -25,7 +25,9 @@
  */
 
 #include "genres.h"
+#include "frame.h"
 #include <QString>
+#include <QVector>
 #include <QMap>
 
 /**
@@ -48,12 +50,12 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Art Rock",               // 149,
   "Audio Theatre",          // 184,
   "Audiobook",              // 183,
-  "Avantgarde",             // 90,
+  "Avant-Garde",            // 90,
   "Ballad",                 // 116,
   "Baroque",                // 150,
   "Bass",                   // 41,
-  "Beat",                   // 135,
-  "Bebob",                  // 85,
+  "Beat Music",             // 135,
+  "Bebop",                  // 85,
   "Bhangra",                // 151,
   "Big Band",               // 96,
   "Big Beat",               // 152,
@@ -62,7 +64,7 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Blues",                  // 0,
   "Booty Bass",             // 107,
   "Breakbeat",              // 153,
-  "BritPop",                // 132,
+  "Britpop",                // 132,
   "Cabaret",                // 65,
   "Celtic",                 // 88,
   "Chamber Music",          // 104,
@@ -82,8 +84,8 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Crossover",              // 139,
   "Cult",                   // 58,
   "Dance",                  // 3,
-  "Dance Hall",             // 125,
-  "Darkwave",               // 50,
+  "Dancehall",              // 125,
+  "Dark Wave",              // 50,
   "Death Metal",            // 22,
   "Disco",                  // 4,
   "Downtempo",              // 155,
@@ -101,17 +103,17 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Electronic",             // 52,
   "Emo",                    // 161,
   "Ethnic",                 // 48,
-  "Euro-House",             // 124,
-  "Euro-Techno",            // 25,
+  "Euro House",             // 124,
+  "Eurotechno",             // 25,
   "Eurodance",              // 54,
   "Experimental",           // 162,
+  "Fast Fusion",            // 84,
   "Folk",                   // 80,
-  "Folk/Rock",              // 81,
+  "Folk Rock",              // 81,
   "Folklore",               // 115,
   "Freestyle",              // 119,
   "Funk",                   // 5,
   "Fusion",                 // 30,
-  "Fusion",                 // 84,
   "G-Funk",                 // 188,
   "Game",                   // 36,
   "Gangsta",                // 59,
@@ -126,7 +128,7 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Hard Rock",              // 79,
   "Hardcore",               // 129,
   "Heavy Metal",            // 137,
-  "Hip-Hop",                // 7,
+  "Hip Hop",                // 7,
   "House",                  // 35,
   "Humour",                 // 100,
   "IDM",                    // 165,
@@ -140,7 +142,7 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Instrumental Rock",      // 47,
   "Jam Band",               // 168,
   "Jazz",                   // 8,
-  "Jazz+Funk",              // 29,
+  "Jazz-Funk",              // 29,
   "Jpop",                   // 146,
   "Jungle",                 // 63,
   "Krautrock",              // 169,
@@ -170,7 +172,7 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Polsk Punk",             // 134,
   "Pop",                    // 13,
   "Pop-Folk",               // 53,
-  "Pop/Funk",               // 62,
+  "Pop-Funk",               // 62,
   "Porn Groove",            // 109,
   "Post-Punk",              // 175,
   "Post-Rock",              // 176,
@@ -212,7 +214,7 @@ const char* Genres::s_genre[Genres::count + 3] = {
   "Swing",                  // 83,
   "Symphonic Rock",         // 94,
   "Symphony",               // 106,
-  "Synthpop",               // 147,
+  "Synth-Pop",              // 147,
   "Tango",                  // 113,
   "Techno",                 // 18,
   "Techno-Industrial",      // 51,
@@ -446,7 +448,7 @@ const char* Genres::getName(int num)
 }
 
 /**
- * Get the index in the alphabethically sorted list from the genre number.
+ * Get the index in the alphabetically sorted list from the genre number.
  *
  * @param num genre number
  *
@@ -490,21 +492,56 @@ int Genres::getNumber(const QString& str)
  * Get a name string from a string with a number or a name.
  * ID3v2 genres can be stored as "9", "(9)", "(9)Metal" or "Metal".
  *
- * @param str genre string.
+ * @param str genre string, it can also reference multiple ID3v1 genres
+ * and have a refinement such as "(9)(138)Viking Metal".
+ * Multiple genres can be separated by Frame::stringListSeparator().
+ *
+ * @return genre name or multiple genre names separated by
+ * Frame::stringListSeparator().
  */
 QString Genres::getNameString(const QString& str)
 {
   if (!str.isEmpty()) {
-    int cpPos, n;
-    bool ok;
-    if ((str[0] == QLatin1Char('(')) && ((cpPos = str.indexOf(QLatin1Char(')'), 2)) > 1)) {
-      n = str.midRef(1, cpPos - 1).toInt(&ok);
-      if (ok && n <= 0xff) {
-        return QString::fromLatin1(getName(n));
+    QStringList genres;
+    const auto parts = str.splitRef(Frame::stringListSeparator());
+    for (const auto& part : parts) {
+      auto s = part.trimmed();
+      // First extract all genre codes which are in parentheses
+      int offset = 0;
+      int end = 0;
+      while (s.length() > offset && s.at(offset) == QLatin1Char('(') &&
+            (end = s.indexOf(QLatin1Char(')'), offset + 1)) > offset) {
+        const auto genreCode = s.mid(offset + 1, end - 1);
+        s = s.mid(end + 1);
+        bool ok;
+        int n = genreCode.toInt(&ok);
+        if (genreCode == QLatin1String("RX") ||
+            genreCode == QLatin1String("CR")) {
+          genres.append(genreCode.toString());
+        } else if (ok && n >= 0 && n <= 0xff) {
+          QString genreText = QString::fromLatin1(getName(n));
+          if (!genreText.isEmpty()) {
+            genres.append(genreText);
+          }
+        }
+      }
+      // Process the rest as a genre code or text
+      s = s.trimmed();
+      if (!s.isEmpty()) {
+        bool ok;
+        int n = s.toInt(&ok);
+        if (ok && n >= 0 && n <= 0xff) {
+          QString genreText = QString::fromLatin1(getName(n));
+          if (!genreText.isEmpty()) {
+            genres.append(genreText);
+          }
+        } else {
+          genres.append(s.toString());
+        }
       }
-    } else if ((n = str.toInt(&ok)) >= 0 && n <= 0xff && ok) {
-      return QString::fromLatin1(getName(n));
     }
+    genres.removeDuplicates();
+    return genres.join(Frame::stringListSeparator());
   }
   return str;
 }
@@ -512,23 +549,46 @@ QString Genres::getNameString(const QString& str)
 /**
  * Get a number representation of a genre name if possible.
  *
- * @param str         string with genre name
- * @param parentheses true to put the number in parentheses
+ * @param str string with genre name, can also contain multiple genres
+ * separated by Frame::stringListSeparator()
+ * @param parentheses true to put the numbers in parentheses, this will
+ * result in an ID3v2.3.0 genre string, which can containing multiple
+ * references to ID3v1 genres and optionally a refinement as a genre text
  *
- * @return genre string.
+ * @return genre string using numbers where possible. If @a parentheses
+ * is true, an ID3v2.3.0 genre string such as "(9)(138)Viking Metal" is
+ * returned, else if @a str contains multiple genres, they are returned
+ * as numbers (where possible) separated by Frame::stringListSeparator().
  */
 QString Genres::getNumberString(const QString& str, bool parentheses)
 {
-  int n = getNumber(str);
-  if (n < 0xff) {
-    if (parentheses) {
-      QString s(QLatin1String("("));
-      s += QString::number(n);
-      s += QLatin1Char(')');
-      return s;
-    } else {
-      return QString::number(n);
+  QStringList genres;
+  QString genreText;
+
+  const auto parts = str.split(Frame::stringListSeparator());
+  for (const auto& part : parts) {
+    auto s = part.trimmed();
+    bool ok;
+    int n = s.toInt(&ok);
+    if (s == QLatin1String("RX") || s == QLatin1String("CR")) {
+      genres.append(s);
+    } else if ((ok && n >= 0 && n <= 255) ||
+               (n = getNumber(s)) < 0xff) {
+      genres.append(QString::number(n));
+    } else if (!parentheses) {
+      genres.append(s);
+    } else if (genreText.isEmpty()) {
+      // For ID3v2.3.0, we can append only one genre text as a refinement
+      genreText = s;
     }
   }
-  return str;
+  if (!parentheses) {
+    return genres.join(Frame::stringListSeparator());
+  } else {
+    if (!genres.isEmpty()) {
+      genreText.prepend(QLatin1Char('(') + genres.join(QLatin1String(")(")) +
+                        QLatin1Char(')'));
+    }
+    return genreText;
+  }
 }
