@@ -1048,7 +1048,8 @@ void TaggedFile::setFrames(Frame::TagNumber tagNr,
               if (myIt->getValue() != it->getValue() ||
                   (!myIt->getFieldList().isEmpty() &&
                    !it->getFieldList().isEmpty() &&
-                   myIt->getFieldList() != it->getFieldList())) {
+                   !Frame::Field::fuzzyCompareFieldLists(myIt->getFieldList(),
+                                                         it->getFieldList()))) {
                 Frame myFrame(*it);
                 myFrame.setIndex(myIndex);
                 setFrame(tagNr, myFrame);
@@ -1151,7 +1152,7 @@ QString TaggedFile::DetailInfo::toString() const
   if (valid) {
     str = format;
     str += QLatin1Char(' ');
-    if (bitrate > 0 && bitrate < 999) {
+    if (bitrate > 0 && bitrate < 16384) {
       if (vbr) str += QLatin1String("VBR ");
       str += QString::number(bitrate);
       str += QLatin1String(" kbps ");
