@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 06 Feb 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -53,32 +53,32 @@ FindReplaceDialog::FindReplaceDialog(QWidget* parent) : QDialog(parent)
   setObjectName(QLatin1String("FindReplaceDialog"));
   setWindowTitle(tr("Find and Replace"));
 
-  QVBoxLayout* vlayout = new QVBoxLayout(this);
+  auto vlayout = new QVBoxLayout(this);
 
-  QGridLayout* findReplaceLayout = new QGridLayout;
+  auto findReplaceLayout = new QGridLayout;
   QLabel* findLabel = new QLabel(tr("F&ind:"));
   m_findEdit = new QComboBox;
   m_findEdit->setEditable(true);
   m_findEdit->completer()->setCaseSensitivity(Qt::CaseSensitive);
-  connect(m_findEdit->lineEdit(), SIGNAL(returnPressed()),
-          this, SLOT(onReturnPressedInFind()));
+  connect(m_findEdit->lineEdit(), &QLineEdit::returnPressed,
+          this, &FindReplaceDialog::onReturnPressedInFind);
   findLabel->setBuddy(m_findEdit);
   m_findButton = new QPushButton(tr("&Find"));
   m_findButton->setAutoDefault(true);
-  connect(m_findButton, SIGNAL(clicked()), this, SLOT(find()));
+  connect(m_findButton, &QAbstractButton::clicked, this, &FindReplaceDialog::find);
   m_replaceLabel = new QLabel(tr("Re&place:"));
   m_replaceEdit = new QComboBox;
   m_replaceEdit->setEditable(true);
   m_replaceEdit->completer()->setCaseSensitivity(Qt::CaseSensitive);
-  connect(m_replaceEdit->lineEdit(), SIGNAL(returnPressed()),
-          this, SLOT(onReturnPressedInReplace()));
+  connect(m_replaceEdit->lineEdit(), &QLineEdit::returnPressed,
+          this, &FindReplaceDialog::onReturnPressedInReplace);
   m_replaceLabel->setBuddy(m_replaceEdit);
   m_replaceButton = new QPushButton(tr("&Replace"));
   m_replaceButton->setAutoDefault(true);
-  connect(m_replaceButton, SIGNAL(clicked()), this, SLOT(replace()));
+  connect(m_replaceButton, &QAbstractButton::clicked, this, &FindReplaceDialog::replace);
   m_replaceAllButton = new QPushButton(tr("Replace &all"));
   m_replaceAllButton->setAutoDefault(false);
-  connect(m_replaceAllButton, SIGNAL(clicked()), this, SLOT(replaceAll()));
+  connect(m_replaceAllButton, &QAbstractButton::clicked, this, &FindReplaceDialog::replaceAll);
 
   findReplaceLayout->addWidget(findLabel, 0, 0);
   findReplaceLayout->addWidget(m_findEdit, 0, 1);
@@ -90,9 +90,9 @@ FindReplaceDialog::FindReplaceDialog(QWidget* parent) : QDialog(parent)
   findReplaceLayout->setColumnStretch(1, 1);
   vlayout->addLayout(findReplaceLayout);
 
-  QHBoxLayout* optionsTagsLayout = new QHBoxLayout;
+  auto optionsTagsLayout = new QHBoxLayout;
   QGroupBox* optionsBox = new QGroupBox(tr("Options"));
-  QVBoxLayout* optionsLayout = new QVBoxLayout(optionsBox);
+  auto optionsLayout = new QVBoxLayout(optionsBox);
   m_matchCaseCheckBox = new QCheckBox(tr("&Match case"));
   optionsLayout->addWidget(m_matchCaseCheckBox);
   m_backwardsCheckBox = new QCheckBox(tr("&Backwards"));
@@ -103,18 +103,19 @@ FindReplaceDialog::FindReplaceDialog(QWidget* parent) : QDialog(parent)
   optionsTagsLayout->addWidget(optionsBox);
 
   QGroupBox* tagsGroupBox = new QGroupBox(tr("&Tags"));
-  QVBoxLayout* tagsLayout = new QVBoxLayout(tagsGroupBox);
+  auto tagsLayout = new QVBoxLayout(tagsGroupBox);
   m_allFramesCheckBox = new QCheckBox(tr("Select a&ll"));
   m_allFramesCheckBox->setChecked(true);
   tagsLayout->addWidget(m_allFramesCheckBox);
-  QListView* tagsListView = new QListView;
+  auto tagsListView = new QListView;
   tagsListView->setDisabled(true);
-  connect(m_allFramesCheckBox, SIGNAL(toggled(bool)),
-          tagsListView, SLOT(setDisabled(bool)));
+  connect(m_allFramesCheckBox, &QAbstractButton::toggled,
+          tagsListView, &QWidget::setDisabled);
   m_tagsModel = new CheckableStringListModel(tagsGroupBox);
   QStringList unifiedFrameNames;
+  unifiedFrameNames.reserve(Frame::FT_LastFrame - Frame::FT_FirstFrame + 2);
   unifiedFrameNames.append(tr("Filename"));
-  for (int i = Frame::FT_FirstFrame; i< Frame::FT_LastFrame; ++i) {
+  for (int i = Frame::FT_FirstFrame; i <= Frame::FT_LastFrame; ++i) {
     unifiedFrameNames.append(
         Frame::ExtendedType(static_cast<Frame::Type>(i)).getTranslatedName());
   }
@@ -124,23 +125,23 @@ FindReplaceDialog::FindReplaceDialog(QWidget* parent) : QDialog(parent)
   optionsTagsLayout->addWidget(tagsGroupBox);
   vlayout->addLayout(optionsTagsLayout);
 
-  QHBoxLayout* hlayout = new QHBoxLayout;
+  auto hlayout = new QHBoxLayout;
   QPushButton* helpButton = new QPushButton(tr("&Help"));
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+  connect(helpButton, &QAbstractButton::clicked, this, &FindReplaceDialog::showHelp);
 
   QPushButton* saveButton = new QPushButton(tr("&Save Settings"));
   saveButton->setAutoDefault(false);
   hlayout->addWidget(saveButton);
-  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
+  connect(saveButton, &QAbstractButton::clicked, this, &FindReplaceDialog::saveConfig);
 
   hlayout->addStretch();
 
   QPushButton* closeButton = new QPushButton(tr("&Close"));
   closeButton->setAutoDefault(false);
   hlayout->addWidget(closeButton);
-  connect(closeButton, SIGNAL(clicked()), this, SLOT(reject()));
+  connect(closeButton, &QAbstractButton::clicked, this, &QDialog::reject);
 
   vlayout->addLayout(hlayout);
 
@@ -155,13 +156,6 @@ FindReplaceDialog::FindReplaceDialog(QWidget* parent) : QDialog(parent)
   readConfig();
 }
 
-/**
- * Destructor.
- */
-FindReplaceDialog::~FindReplaceDialog()
-{
-}
-
 /**
  * Initialize dialog before it is displayed.
  * @param findOnly true to display only find part of dialog
