@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 19 Jun 2011
  *
- * Copyright (C) 2011-2013  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -50,49 +50,45 @@
  */
 TextImportDialog::TextImportDialog(IPlatformTools* platformTools,
                                    QWidget* parent,
-                                   TrackDataModel* trackDataModel) :
-  QDialog(parent), m_platformTools(platformTools),
-  m_textImporter(new TextImporter(trackDataModel))
+                                   TrackDataModel* trackDataModel)
+  : QDialog(parent), m_platformTools(platformTools),
+    m_textImporter(new TextImporter(trackDataModel))
 {
   setObjectName(QLatin1String("TextImportDialog"));
   setWindowTitle(tr("Import from File/Clipboard"));
   setSizeGripEnabled(true);
 
-  QVBoxLayout* vboxLayout = new QVBoxLayout(this);
+  auto vboxLayout = new QVBoxLayout(this);
 
   QString formatToolTip = ImportParser::getFormatToolTip();
   m_formatListEdit = new FormatListEdit(
-        QStringList() << tr("Format:")
-                      << tr("Header:")
-                      << tr("Tracks:"),
-        QStringList() << QString()
-                      << formatToolTip
-                      << formatToolTip,
+        {tr("Format:"), tr("Header:"), tr("Tracks:")},
+        {QString(), formatToolTip, formatToolTip},
         this);
   vboxLayout->addWidget(m_formatListEdit);
 
-  QHBoxLayout* buttonLayout = new QHBoxLayout;
+  auto buttonLayout = new QHBoxLayout;
   QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   buttonLayout->addWidget(helpButton);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+  connect(helpButton, &QAbstractButton::clicked, this, &TextImportDialog::showHelp);
   QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   buttonLayout->addWidget(saveButton);
-  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
+  connect(saveButton, &QAbstractButton::clicked, this, &TextImportDialog::saveConfig);
   buttonLayout->addStretch();
   QPushButton* fileButton = new QPushButton(tr("From F&ile..."), this);
   fileButton->setAutoDefault(false);
   buttonLayout->addWidget(fileButton);
-  connect(fileButton, SIGNAL(clicked()), this, SLOT(fromFile()));
+  connect(fileButton, &QAbstractButton::clicked, this, &TextImportDialog::fromFile);
   QPushButton* clipButton = new QPushButton(tr("From Clip&board"), this);
   clipButton->setAutoDefault(false);
   buttonLayout->addWidget(clipButton);
-  connect(clipButton, SIGNAL(clicked()), this, SLOT(fromClipboard()));
+  connect(clipButton, &QAbstractButton::clicked, this, &TextImportDialog::fromClipboard);
   QPushButton* closeButton = new QPushButton(tr("&Close"), this);
   closeButton->setAutoDefault(false);
   buttonLayout->addWidget(closeButton);
-  connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));
+  connect(closeButton, &QAbstractButton::clicked, this, &QDialog::accept);
   vboxLayout->addLayout(buttonLayout);
 }
 
@@ -101,7 +97,7 @@ TextImportDialog::TextImportDialog(IPlatformTools* platformTools,
  */
 TextImportDialog::~TextImportDialog()
 {
-  delete m_textImporter;
+  // Must not be inline because of forwared declared QScopedPointer.
 }
 
 /**
@@ -119,9 +115,8 @@ void TextImportDialog::setFormatFromConfig()
 {
   const ImportConfig& importCfg = ImportConfig::instance();
   m_formatListEdit->setFormats(
-        QList<QStringList>() << importCfg.importFormatNames()
-                             << importCfg.importFormatHeaders()
-                             << importCfg.importFormatTracks(),
+        {importCfg.importFormatNames(), importCfg.importFormatHeaders(),
+         importCfg.importFormatTracks()},
         importCfg.importFormatIndex());
 }
 
@@ -161,7 +156,7 @@ bool TextImportDialog::importFromFile(const QString& fn)
 void TextImportDialog::fromFile()
 {
   importFromFile(m_platformTools->getOpenFileName(this, QString(),
-      ImportConfig::instance().importDir(), QString(), 0)
+      ImportConfig::instance().importDir(), QString(), nullptr)
     );
 }
 
