@@ -40,6 +40,10 @@
 #include <QToolBar>
 #include <QStatusBar>
 #include <QApplication>
+#ifdef Q_OS_MAC
+#include <sys/stat.h>
+#include <unistd.h>
+#endif
 #include "kid3form.h"
 #include "kid3application.h"
 #include "framelist.h"
@@ -188,6 +192,7 @@ void BaseMainWindowImpl::init()
   m_w->resize(m_w->sizeHint());
 
   readOptions();
+  applyChangedShortcuts();
 }
 
 /**
@@ -364,6 +369,15 @@ void BaseMainWindowImpl::saveDirectory(bool updateGui)
         TaggedFile* taggedFile;
         const auto filePaths = notWritableFiles;
         for (const QString& filePath : filePaths) {
+#ifdef Q_OS_MAC
+          // On macOS, files may be locked, so try to make them mutable.
+          const auto utf8Path = filePath.toUtf8();
+          struct stat st;
+          if (::stat(utf8Path.constData(), &st) == 0 &&
+              st.st_flags & UF_IMMUTABLE) {
+            ::chflags(utf8Path.constData(), st.st_flags & ~UF_IMMUTABLE);
+          }
+#endif
           QFile::setPermissions(filePath,
               QFile::permissions(filePath) | QFile::WriteUser);
           if (model &&
@@ -950,6 +964,15 @@ void BaseMainWindowImpl::applyChangedConfiguration()
   }
 }
 
+/**
+ * Apply keyboard shortcut changes.
+ */
+void BaseMainWindowImpl::applyChangedShortcuts()
+{
+  auto shortcuts = m_self->shortcutsMap();
+  m_form->setSectionActionShortcuts(shortcuts);
+}
+
 /**
  * Find and replace in tags of files.
  * @param findOnly true to display only find part of dialog
