@@ -33,14 +33,17 @@
 #include "frame.h"
 #include "kid3api.h"
 
+class QLabel;
 class QProgressBar;
 class QToolButton;
 class QItemSelection;
+class QTimer;
 class ProgressWidget;
 class Kid3Form;
 class Kid3Application;
 class TaggedFile;
 class ImportDialog;
+class TagImportDialog;
 class BatchImportDialog;
 class ExportDialog;
 class FindReplaceDialog;
@@ -141,6 +144,12 @@ public:
    */
   void init();
 
+  /**
+   * Change visibility of status bar.
+   * @param visible true to show status bar
+   */
+  void setStatusBarVisible(bool visible);
+
   /**
    * Update modification state before closing.
    * If anything was modified, save after asking user.
@@ -165,6 +174,11 @@ public:
    */
   void applyChangedConfiguration();
 
+  /**
+   * Apply keyboard shortcut changes.
+   */
+  void applyChangedShortcuts();
+
   /**
    * Access to application.
    * @return application.
@@ -229,6 +243,12 @@ public slots:
    */
   void slotStatusMsg(const QString& text);
 
+  /**
+   * Clear status message.
+   * To be called when a message set with slotStatusMsg() is no longer valid.
+   */
+  void slotClearStatusMsg();
+
   /**
    * Show playlist dialog.
    */
@@ -252,6 +272,11 @@ public slots:
    */
   void slotImport();
 
+  /**
+   * Tag import.
+   */
+  void slotTagImport();
+
   /**
    * Batch import.
    */
@@ -438,6 +463,16 @@ private slots:
   void showOperationProgress(const QString& name, int done, int total,
                              bool* abort);
 
+  /**
+   * Called when the item count of the file proxy model changed.
+   */
+  void onItemCountChanged();
+
+  /**
+   * Called when the item count of the file selection model changed.
+   */
+  void onSelectionCountChanged();
+
 private:
   /**
    * Free allocated resources.
@@ -540,16 +575,27 @@ private:
    */
   void checkProgressMonitoring(int done, int total, const QString& text);
 
+  /**
+   * Update label of status bar with information about the number of files.
+   */
+  void updateStatusLabel();
+
   IPlatformTools* m_platformTools;
   QMainWindow* m_w;
   BaseMainWindow* m_self;
 
+  QTimer* m_deferredItemCountTimer;
+  QTimer* m_deferredSelectionCountTimer;
+  /** Label with normal status message */
+  QLabel* m_statusLabel;
   /** GUI with controls */
   Kid3Form* m_form;
   /** Application logic */
   Kid3Application* m_app;
   /** Import dialog */
   QScopedPointer<ImportDialog> m_importDialog;
+  /** Import from Tags dialog */
+  QScopedPointer<TagImportDialog> m_tagImportDialog;
   /** Batch import dialog */
   QScopedPointer<BatchImportDialog> m_batchImportDialog;
   /** Browse cover art dialog */
@@ -572,6 +618,7 @@ private:
   QMap<QString, PlaylistEditDialog*> m_playlistEditDialogs;
   /** Progress dialog */
   ProgressWidget* m_progressWidget;
+  QLabel* m_progressLabel;
   QProgressBar* m_progressBar;
   QToolButton* m_progressAbortButton;
   /** Edit frame dialog */
@@ -584,6 +631,9 @@ private:
   QDateTime m_progressStartTime;
   QString m_progressTitle;
   void (BaseMainWindowImpl::*m_progressTerminationHandler)();
+  int m_folderCount;
+  int m_fileCount;
+  int m_selectionCount;
   bool m_progressDisconnected;
   bool m_findReplaceActive;
   bool m_expandNotificationNeeded;
@@ -622,6 +672,12 @@ public:
    */
   virtual void initActions() = 0;
 
+  /**
+   * Get keyboard shortcuts.
+   * @return mapping of action names to key sequences.
+   */
+  virtual QMap<QString, QKeySequence> shortcutsMap() const = 0;
+
   /**
    * Add directory to recent files list.
    *
@@ -690,11 +746,10 @@ protected:
   void init();
 
   /**
-   * Change status message.
-   *
-   * @param text message
+   * Change visibility of status bar.
+   * @param visible true to show status bar
    */
-  void slotStatusMsg(const QString& text);
+  void setStatusBarVisible(bool visible);
 
   /**
    * Update modification state before closing.
