@@ -67,9 +67,10 @@
 #include "formatconfig.h"
 #include "dirproxymodel.h"
 #include "fileproxymodel.h"
-#include "filesystemmodel.h"
 #include "coretaggedfileiconprovider.h"
+#include "icoreplatformtools.h"
 #include "kid3application.h"
+#include "sectionactions.h"
 #ifdef Q_OS_MAC
 #include <CoreFoundation/CFURL.h>
 #endif
@@ -300,8 +301,14 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
   m_dirListBox->setRootIsDecorated(false);
   m_dirListBox->setModel(m_app->getDirProxyModel());
   m_dirListBox->setSelectionModel(m_app->getDirSelectionModel());
+  connect(m_fileListBox, &QAbstractItemView::activated,
+          this, &Kid3Form::fileActivated);
   connect(m_dirListBox, &QAbstractItemView::activated, this,
       &Kid3Form::dirSelected);
+  connect(m_fileListBox, &ConfigurableTreeView::parentActivated,
+          this, &Kid3Form::openParentDirectory);
+  connect(m_dirListBox, &ConfigurableTreeView::parentActivated,
+          this, &Kid3Form::openParentDirectory);
 
   connect(m_app, &Kid3Application::fileRootIndexChanged,
           this, &Kid3Form::setFileRootIndex);
@@ -442,8 +449,10 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
     rightHalfLayout->addWidget(m_tagWidget[tagNr], 100);
 
     auto idHBoxLayout = new QHBoxLayout(m_tagWidget[tagNr]);
+    FrameTableModel* frameModel = m_app->frameModel(tagNr);
+    frameModel->setHeadersEmpty(true);
     m_frameTable[tagNr] = new FrameTable(
-          m_app->frameModel(tagNr), m_app->genreModel(tagNr), m_tagWidget[tagNr]);
+          frameModel, m_app->genreModel(tagNr), m_tagWidget[tagNr]);
     m_frameTable[tagNr]->setSelectionModel(m_app->getFramesSelectionModel(tagNr));
     idHBoxLayout->addWidget(m_frameTable[tagNr], tagNr == Frame::Tag_Id3v1 ? 100 : 0);
     m_tagLabel[tagNr]->setBuddy(m_frameTable[tagNr]);
@@ -579,6 +588,80 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
     setTabOrder(tabWidget, m_frameTable[tagNr]);
     tabWidget = m_frameTable[tagNr];
   }
+
+  auto sectionActions = new SectionActions(SectionActions::Navigation,
+                                           m_fileListBox);
+  m_sectionActions.append(sectionActions);
+  connect(sectionActions->previousSectionAction(), &QAction::triggered,
+          this, [this]() { setFocusPreviousTag(Frame::Tag_NumValues); });
+  connect(sectionActions->nextSectionAction(), &QAction::triggered,
+          this, &Kid3Form::setFocusDirList);
+
+  sectionActions = new SectionActions(SectionActions::Navigation, m_dirListBox);
+  m_sectionActions.append(sectionActions);
+  connect(sectionActions->previousSectionAction(), &QAction::triggered,
+          this, &Kid3Form::setFocusFileList);
+  connect(sectionActions->nextSectionAction(), &QAction::triggered,
+          this, &Kid3Form::setFocusFilename);
+
+  sectionActions = new SectionActions(SectionActions::Navigation |
+                                      SectionActions::Transfer,
+                                      m_fileWidget);
+  m_sectionActions.append(sectionActions);
+  connect(sectionActions->previousSectionAction(), &QAction::triggered,
+          this, &Kid3Form::setFocusDirList);
+  connect(sectionActions->nextSectionAction(), &QAction::triggered,
+          this, [this]() { setFocusNextTag(Frame::Tag_NumValues); });
+  connect(sectionActions->transferAction(), &QAction::triggered,
+    m_app->tag(Frame::Tag_2), &Kid3ApplicationTagContext::getFilenameFromTags);
+
+  FOR_ALL_TAGS(tagNr) {
+    sectionActions = new SectionActions(
+          tagNr == Frame::Tag_1 ? SectionActions::Navigation |
+                                  SectionActions::Transfer |
+                                  SectionActions::EditSection
+                                : SectionActions::Navigation |
+                                  SectionActions::Transfer |
+                                  SectionActions::EditSection |
+                                  SectionActions::EditElement,
+          m_frameTable[tagNr]);
+    m_sectionActions.append(sectionActions);
+    connect(sectionActions->previousSectionAction(), &QAction::triggered,
+            this, [this, tagNr]() {
+      setFocusPreviousTag(tagNr);
+    });
+    connect(sectionActions->nextSectionAction(), &QAction::triggered,
+            this, [this, tagNr]() {
+      setFocusNextTag(tagNr);
+    });
+
+    connect(sectionActions->copyAction(), &QAction::triggered,
+            m_app->tag(tagNr), &Kid3ApplicationTagContext::copyTags);
+    connect(sectionActions->pasteAction(), &QAction::triggered,
+            m_app->tag(tagNr), &Kid3ApplicationTagContext::pasteTags);
+    connect(sectionActions->removeAction(), &QAction::triggered,
+            this, [this, tagNr]() {
+      m_app->tag(tagNr)->removeTags();
+      setFocusTag(tagNr);
+    });
+
+    QByteArray ba;
+    ba.append(static_cast<char>(tagNr == Frame::Tag_2 ? Frame::Tag_1
+                                                      : Frame::Tag_2));
+    ba.append(static_cast<char>(tagNr));
+    sectionActions->transferAction()->setData(ba);
+    connect(sectionActions->transferAction(), &QAction::triggered,
+            this, &Kid3Form::copyTagsActionData);
+
+    if (tagNr != Frame::Tag_1) {
+      connect(sectionActions->editAction(), &QAction::triggered,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::editFrame);
+      connect(sectionActions->addAction(), &QAction::triggered,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::addFrame);
+      connect(sectionActions->deleteAction(), &QAction::triggered,
+              m_app->tag(tagNr), &Kid3ApplicationTagContext::deleteFrame);
+    }
+  }
 }
 
 /**
@@ -589,6 +672,19 @@ Kid3Form::~Kid3Form()
   m_app->removeFrameEditor(m_mainWin);
 }
 
+/**
+ * Set keyboard shortcuts for section actions.
+ * @param map map of action names to key sequences
+ */
+void Kid3Form::setSectionActionShortcuts(const QMap<QString, QKeySequence>& map)
+{
+  for (SectionActions* sectionActions : m_sectionActions) {
+    sectionActions->setShortcuts(map);
+  }
+  m_fileListBox->setShortcuts(map);
+  m_dirListBox->setShortcuts(map);
+}
+
 /**
  * Handle event when mouse is moved while dragging.
  *
@@ -668,10 +764,13 @@ void Kid3Form::nameLineEditChanged(const QString& txt)
  */
 void Kid3Form::markChangedFilename(bool en)
 {
-  if (en) {
+  CoreTaggedFileIconProvider* colorProvider;
+  if (en &&
+      (colorProvider = m_app->getPlatformTools()->iconProvider()) != nullptr) {
     QPalette changedPalette(m_nameLabel->palette());
     changedPalette.setBrush(QPalette::Active, QPalette::Window,
-                            changedPalette.mid());
+                            colorProvider->colorForContext(ColorContext::Marked)
+                            .value<QBrush>());
     m_nameLabel->setPalette(changedPalette);
   } else {
     m_nameLabel->setPalette(QPalette());
@@ -716,6 +815,45 @@ void Kid3Form::dirSelected(const QModelIndex& index)
   }
 }
 
+/**
+ * File list box item activated.
+ *
+ * @param index selected item
+ */
+void Kid3Form::fileActivated(const QModelIndex& index)
+{
+  if (const FileProxyModel* fileProxyModel =
+      qobject_cast<const FileProxyModel*>(index.model())) {
+    if (fileProxyModel->isDir(index)) {
+      QString dirPath = fileProxyModel->filePath(index);
+      if (!dirPath.isEmpty()) {
+        m_mainWin->updateCurrentSelection();
+        m_mainWin->confirmedOpenDirectory({dirPath});
+      }
+    }
+  }
+}
+
+/**
+ * Open the parent directory of a model index.
+ *
+ * @param index current root index of item view
+ */
+void Kid3Form::openParentDirectory(const QModelIndex& index)
+{
+  if (index.isValid()) {
+    QDir dir(index.data(FileSystemModel::FilePathRole).toString());
+    if (dir.cdUp()) {
+      QString dirPath = dir.absolutePath();
+      if (m_dirListBox && index.model() == m_dirListBox->model()) {
+        m_app->setDirUpIndex(index);
+      }
+      m_mainWin->updateCurrentSelection();
+      m_mainWin->confirmedOpenDirectory({dirPath});
+    }
+  }
+}
+
 /**
  * Enable or disable controls requiring tags.
  * @param tagNr tag number
@@ -845,32 +983,13 @@ void Kid3Form::onFirstDirectoryOpened()
   const GuiConfig& guiCfg = GuiConfig::instance();
   m_app->getFileProxyModel()->sort(guiCfg.fileListSortColumn(),
                                    guiCfg.fileListSortOrder());
-  int firstFileSectionSize = 0;
-  const QHeaderView* fileHeader = m_fileListBox->header();
-  const auto columns = guiCfg.fileListVisibleColumns();
-  for (int column : columns) {
-    m_fileListBox->resizeColumnToContents(column);
-    if (firstFileSectionSize <= 0 && fileHeader) {
-      firstFileSectionSize = fileHeader->sectionSize(column);
-    }
-  }
+  int firstFileSectionSize =
+      m_fileListBox->initializeColumnWidthsFromContents(-1);
   m_fileListBox->scrollTo(m_fileListBox->currentIndex());
-
-  int firstDirSectionSize = 0;
-  QHeaderView* dirHeader = m_dirListBox->header();
-  const auto dirColumns = guiCfg.dirListVisibleColumns();
-  for (int column : dirColumns) {
-    m_dirListBox->resizeColumnToContents(column);
-    if (firstDirSectionSize <= 0 && dirHeader) {
-      firstDirSectionSize = dirHeader->sectionSize(column);
-      if (firstDirSectionSize < firstFileSectionSize) {
-        // The directory column often only contains "." and "..", which results
-        // in a small size. Make it at least as wide as the corresponding
-        // file list column.
-        dirHeader->resizeSection(column, firstFileSectionSize);
-      }
-    }
-  }
+  // The directory column often only contains "." and "..", which results
+  // in a small size. Make it at least as wide as the corresponding
+  // file list column.
+  m_dirListBox->initializeColumnWidthsFromContents(firstFileSectionSize);
 }
 
 /**
@@ -895,7 +1014,14 @@ void Kid3Form::hidePicture(bool hide)
  */
 void Kid3Form::setFocusFilename()
 {
-  m_nameLineEdit->setFocus();
+  if (m_fileWidget->isHidden()) {
+    hideFile(false);
+  }
+  if (isFilenameEditEnabled()) {
+    m_nameLineEdit->setFocus();
+  } else {
+    m_formatComboBox->setFocus();
+  }
 }
 
 /**
@@ -904,9 +1030,55 @@ void Kid3Form::setFocusFilename()
  */
 void Kid3Form::setFocusTag(Frame::TagNumber tagNr)
 {
+  if (m_tagWidget[tagNr]->isHidden()) {
+    hideTag(tagNr, false);
+  }
   m_frameTable[tagNr]->setFocus();
 }
 
+/**
+ * Set focus on next tag controls.
+ * @param tagNr current tag, Frame::Tag_NumValues if not on tag
+ */
+void Kid3Form::setFocusNextTag(Frame::TagNumber tagNr)
+{
+  for (int i = tagNr == Frame::Tag_NumValues ? Frame::Tag_1
+                                             : tagNr + 1; ; ++i) {
+    if (i >= Frame::Tag_NumValues) {
+      setFocusFileList();
+      break;
+    } else if (i >= Frame::Tag_1) {
+      if (m_tagWidget[i]->isEnabled()) {
+        setFocusTag(static_cast<Frame::TagNumber>(i));
+        break;
+      }
+    } else {
+      break;
+    }
+  }
+}
+
+/**
+ * Set focus on previous tag controls.
+ * @param tagNr current tag, Frame::Tag_NumValues if not on tag
+ */
+void Kid3Form::setFocusPreviousTag(Frame::TagNumber tagNr)
+{
+  for (int i = tagNr - 1; ; --i) {
+    if (i < Frame::Tag_1) {
+      setFocusFilename();
+      break;
+    } else if (i < Frame::Tag_NumValues) {
+      if (m_tagWidget[i]->isEnabled()) {
+        setFocusTag(static_cast<Frame::TagNumber>(i));
+        break;
+      }
+    } else {
+      break;
+    }
+  }
+}
+
 /**
  * Set focus on file list.
  */
@@ -948,10 +1120,20 @@ void Kid3Form::saveConfig()
   guiCfg.setFileListSortColumn(column);
   guiCfg.setFileListSortOrder(order);
   guiCfg.setFileListVisibleColumns(m_fileListBox->getVisibleColumns());
+  bool customColumWidthsEnabled = m_fileListBox->areCustomColumnWidthsEnabled();
+  guiCfg.setFileListCustomColumnWidthsEnabled(customColumWidthsEnabled);
+  if (customColumWidthsEnabled) {
+    guiCfg.setFileListColumnWidths(m_fileListBox->getColumnWidths());
+  }
   m_dirListBox->getSortByColumn(column, order);
   guiCfg.setDirListSortColumn(column);
   guiCfg.setDirListSortOrder(order);
   guiCfg.setDirListVisibleColumns(m_dirListBox->getVisibleColumns());
+  customColumWidthsEnabled = m_dirListBox->areCustomColumnWidthsEnabled();
+  guiCfg.setDirListCustomColumnWidthsEnabled(customColumWidthsEnabled);
+  if (customColumWidthsEnabled) {
+    guiCfg.setDirListColumnWidths(m_dirListBox->getColumnWidths());
+  }
 }
 
 /**
@@ -989,9 +1171,15 @@ void Kid3Form::readConfig()
   m_fileListBox->sortByColumn(guiCfg.fileListSortColumn(),
                               guiCfg.fileListSortOrder());
   m_fileListBox->setVisibleColumns(guiCfg.fileListVisibleColumns());
+  m_fileListBox->setColumnWidths(guiCfg.fileListColumnWidths());
+  m_fileListBox->setCustomColumnWidthsEnabled(
+        guiCfg.fileListCustomColumnWidthsEnabled());
   m_dirListBox->sortByColumn(guiCfg.dirListSortColumn(),
                              guiCfg.dirListSortOrder());
   m_dirListBox->setVisibleColumns(guiCfg.dirListVisibleColumns());
+  m_dirListBox->setColumnWidths(guiCfg.dirListColumnWidths());
+  m_dirListBox->setCustomColumnWidthsEnabled(
+        guiCfg.dirListCustomColumnWidthsEnabled());
 }
 
 /**
