@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 28 May 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef COMBOBOXDELEGATE_H
-#define COMBOBOXDELEGATE_H
+#pragma once
 
 #include <QStyledItemDelegate>
 
@@ -38,12 +37,12 @@ public:
    * Constructor.
    * @param parent parent object
    */
-  explicit ComboBoxDelegate(QObject* parent = 0);
+  explicit ComboBoxDelegate(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~ComboBoxDelegate();
+  virtual ~ComboBoxDelegate() override = default;
 
   /**
    * Create an editor to edit the cells contents.
@@ -54,17 +53,15 @@ public:
    */
   virtual QWidget* createEditor(QWidget* parent,
                                 const QStyleOptionViewItem& option,
-                                const QModelIndex& index ) const;
+                                const QModelIndex& index ) const override;
 
   /**
    * Set data to be edited by the editor.
    * @param editor editor widget
    * @param index  index of item
    */
-  virtual void setEditorData(QWidget* editor, const QModelIndex& index) const;
+  virtual void setEditorData(QWidget* editor, const QModelIndex& index) const override;
 
   virtual void setModelData(QWidget* editor, QAbstractItemModel* model,
-                            const QModelIndex& index) const;
+                            const QModelIndex& index) const override;
 };
-
-#endif // COMBOBOXDELEGATE_H
