@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 14 Apr 2007
  *
- * Copyright (C) 2007  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef STRINGLISTEDIT_H
-#define STRINGLISTEDIT_H
+#pragma once
 
 #include "abstractlistedit.h"
 
@@ -41,23 +40,21 @@ public:
    * @param model item model, e.g. a QStringListModel
    * @param parent parent widget
    */
-  explicit StringListEdit(QAbstractItemModel* model, QWidget* parent = 0);
+  explicit StringListEdit(QAbstractItemModel* model, QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~StringListEdit();
+  virtual ~StringListEdit() override = default;
 
 public slots:
   /**
    * Add a new item.
    */
-  virtual void addItem();
+  virtual void addItem() override;
 
   /**
    * Edit the selected item.
    */
-  virtual void editItem();
+  virtual void editItem() override;
 };
-
-#endif // STRINGLISTEDIT_H
