@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 15 Sep 2005
  *
- * Copyright (C) 2005-2012  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MUSICBRAINZCLIENT_H
-#define MUSICBRAINZCLIENT_H
+#pragma once
 
 #include <QObject>
 #include "servertrackimporter.h"
@@ -37,8 +36,7 @@ class FingerprintCalculator;
 /**
  * MusicBrainz client.
  */
-class MusicBrainzClient : public ServerTrackImporter
-{
+class MusicBrainzClient : public ServerTrackImporter {
   Q_OBJECT
 public:
   /**
@@ -54,55 +52,42 @@ public:
   /**
    * Destructor.
    */
-  virtual ~MusicBrainzClient();
+  virtual ~MusicBrainzClient() override = default;
 
   /**
    * Name of import source.
    * @return name.
    */
-  virtual const char* name() const;
+  virtual const char* name() const override;
 
   /** NULL-terminated array of server strings, 0 if not used */
-  virtual const char** serverList() const;
+  virtual const char** serverList() const override;
 
   /** default server, 0 to disable */
-  virtual const char* defaultServer() const;
+  virtual const char* defaultServer() const override;
 
   /** anchor to online help, 0 to disable */
-  virtual const char* helpAnchor() const;
+  virtual const char* helpAnchor() const override;
 
   /** configuration, 0 if not used */
-  virtual ServerImporterConfig* config() const;
+  virtual ServerImporterConfig* config() const override;
 
   /**
    * Set configuration.
    *
    * @param cfg import server configuration, 0 if not used
    */
-  virtual void setConfig(const ServerImporterConfig* cfg);
+  virtual void setConfig(const ServerImporterConfig* cfg) override;
 
   /**
    * Add the files in the file list.
    */
-  virtual void start();
+  virtual void start() override;
 
   /**
    * Reset the client state.
    */
-  virtual void stop();
-
-signals:
-  /**
-   * Emitted when status of a file changed.
-   * Parameter: index of file, status text
-   */
-  void statusChanged(int, QString);
-
-  /**
-   * Emitted when results for a file are received.
-   * Parameter index of file, track data list
-   */
-  void resultsReceived(int, ImportTrackDataVector&);
+  virtual void stop() override;
 
 private slots:
   void receiveBytes(const QByteArray& bytes);
@@ -130,5 +115,3 @@ private:
   ImportTrackDataVector m_currentTrackData;
   QMap<QByteArray, QByteArray> m_headers;
 };
-
-#endif // MUSICBRAINZCLIENT_H
