@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 18 Jan 2004
  *
- * Copyright (C) 2004-2007  Urs Fleisch
+ * Copyright (C) 2004-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FREEDBCONFIG_H
-#define FREEDBCONFIG_H
+#pragma once
 
 #include "serverimporterconfig.h"
 
@@ -45,14 +44,14 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FreedbConfig();
+  virtual ~FreedbConfig() override = default;
 
   /**
    * Read persisted configuration.
    *
    * @param config KDE configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  virtual void readFromConfig(ISettings* config) override;
 
 private:
   friend FreedbConfig&
@@ -76,14 +75,14 @@ public:
   /**
    * Destructor.
    */
-  virtual ~TrackTypeConfig();
+  virtual ~TrackTypeConfig() override = default;
 
   /**
    * Read persisted configuration.
    *
    * @param config KDE configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  virtual void readFromConfig(ISettings* config) override;
 
 private:
   friend TrackTypeConfig&
@@ -92,5 +91,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif
