@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2011  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,9 +24,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MP3FILE_H
-#define MP3FILE_H
+#pragma once
 
+#include <QScopedPointer>
 #include "taggedfile.h"
 #include "tagconfig.h"
 
@@ -48,26 +48,26 @@ public:
   /**
    * Destructor.
    */
-  virtual ~Mp3File();
+  virtual ~Mp3File() override;
 
   /**
    * Get key of tagged file format.
    * @return "Id3libMetadata".
    */
-  virtual QString taggedFileKey() const;
+  virtual QString taggedFileKey() const override;
 
   /**
    * Get features supported.
    * @return bit mask with Feature flags set.
    */
-  virtual int taggedFileFeatures() const;
+  virtual int taggedFileFeatures() const override;
 
   /**
    * Read tags from file.
    *
    * @param force true to force reading even if tags were already read.
    */
-  virtual void readTags(bool force);
+  virtual void readTags(bool force) override;
 
   /**
    * Write tags to file and rename it if necessary.
@@ -80,14 +80,14 @@ public:
    *
    * @return true if ok, false if the file could not be written or renamed.
    */
-  virtual bool writeTags(bool force, bool* renamed, bool preserve);
+  virtual bool writeTags(bool force, bool* renamed, bool preserve) override;
 
   /**
    * Free resources allocated when calling readTags().
    *
    * @param force true to force clearing even if the tags are modified
    */
-  virtual void clearTags(bool force);
+  virtual void clearTags(bool force) override;
 
   /**
    * Remove frames.
@@ -95,7 +95,7 @@ public:
    * @param tagNr tag number
    * @param flt filter specifying which frames to remove
    */
-  virtual void deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt);
+  virtual void deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt) override;
 
   /**
    * Check if tag information has already been read.
@@ -104,7 +104,7 @@ public:
    *         false if the tags have not been read yet, in which case
    *         hasTag() does not return meaningful information.
    */
-  virtual bool isTagInformationRead() const;
+  virtual bool isTagInformationRead() const override;
 
   /**
    * Check if file has a tag.
@@ -113,7 +113,7 @@ public:
    * @return true if a tag is available.
    * @see isTagInformationRead()
    */
-  virtual bool hasTag(Frame::TagNumber tagNr) const;
+  virtual bool hasTag(Frame::TagNumber tagNr) const override;
 
   /**
    * Check if tags are supported by the format of this file.
@@ -121,14 +121,14 @@ public:
    * @param tagNr tag number
    * @return true.
    */
-  virtual bool isTagSupported(Frame::TagNumber tagNr) const;
+  virtual bool isTagSupported(Frame::TagNumber tagNr) const override;
 
   /**
    * Get technical detail information.
    *
    * @param info the detail information is returned here
    */
-  virtual void getDetailInfo(DetailInfo& info) const;
+  virtual void getDetailInfo(DetailInfo& info) const override;
 
   /**
    * Get duration of file.
@@ -136,14 +136,14 @@ public:
    * @return duration in seconds,
    *         0 if unknown.
    */
-  virtual unsigned getDuration() const;
+  virtual unsigned getDuration() const override;
 
   /**
    * Get file extension including the dot.
    *
    * @return file extension ".mp3".
    */
-  virtual QString getFileExtension() const;
+  virtual QString getFileExtension() const override;
 
   /**
    * Get the format of tag.
@@ -152,7 +152,7 @@ public:
    * @return string describing format of tag,
    *         e.g. "ID3v1.1", "ID3v2.3", "ID3v2.4".
    */
-  virtual QString getTagFormat(Frame::TagNumber tagNr) const;
+  virtual QString getTagFormat(Frame::TagNumber tagNr) const override;
 
   /**
    * Get a specific frame from the tags.
@@ -163,7 +163,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) const;
+  virtual bool getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) const override;
 
   /**
    * Set a frame in the tags.
@@ -173,7 +173,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool setFrame(Frame::TagNumber tagNr, const Frame& frame);
+  virtual bool setFrame(Frame::TagNumber tagNr, const Frame& frame) override;
 
   /**
    * Add a frame in the tags.
@@ -183,7 +183,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool addFrame(Frame::TagNumber tagNr, Frame& frame);
+  virtual bool addFrame(Frame::TagNumber tagNr, Frame& frame) override;
 
   /**
    * Delete a frame from the tags.
@@ -193,7 +193,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool deleteFrame(Frame::TagNumber tagNr, const Frame& frame);
+  virtual bool deleteFrame(Frame::TagNumber tagNr, const Frame& frame) override;
 
   /**
    * Get all frames in tag.
@@ -201,14 +201,14 @@ public:
    * @param tagNr tag number
    * @param frames frame collection to set.
    */
-  virtual void getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames);
+  virtual void getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames) override;
 
   /**
    * Get a list of frame IDs which can be added.
    * @param tagNr tag number
    * @return list with frame IDs.
    */
-  virtual QStringList getFrameIds(Frame::TagNumber tagNr) const;
+  virtual QStringList getFrameIds(Frame::TagNumber tagNr) const override;
 
   /**
    * Add a suitable field list for the frame if missing.
@@ -218,7 +218,7 @@ public:
    * @param tagNr tag number
    * @param frame frame where field list is added
    */
-  virtual void addFieldList(Frame::TagNumber tagNr, Frame& frame) const;
+  virtual void addFieldList(Frame::TagNumber tagNr, Frame& frame) const override;
 
   /**
    * Notify about configuration change.
@@ -271,10 +271,8 @@ private:
   static void setDefaultTextEncoding(TagConfig::TextEncoding textEnc);
 
   /** ID3v1 tags */
-  ID3_Tag* m_tagV1;
+  QScopedPointer<ID3_Tag> m_tagV1;
 
   /** ID3v2 tags */
-  ID3_Tag* m_tagV2;
+  QScopedPointer<ID3_Tag> m_tagV2;
 };
-
-#endif // MP3FILE_H
