@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 23 Sep 2014
  *
- * Copyright (C) 2014-2017  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,12 +27,8 @@
 #include "checkablelistmodel.h"
 #include <QItemSelectionModel>
 
-CheckableListModel::CheckableListModel(QObject* parent) :
-  QAbstractProxyModel(parent), m_selModel(0)
-{
-}
-
-CheckableListModel::~CheckableListModel()
+CheckableListModel::CheckableListModel(QObject* parent)
+  : QAbstractProxyModel(parent), m_selModel(nullptr)
 {
 }
 
@@ -45,15 +41,15 @@ void CheckableListModel::setSelectionModel(QItemSelectionModel* selModel)
 {
   if (m_selModel != selModel) {
     if (m_selModel) {
-      disconnect(m_selModel, 0, this, 0);
+      disconnect(m_selModel, nullptr, this, nullptr);
     }
     m_selModel = selModel;
     if (m_selModel) {
       connect(m_selModel,
-              SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-              this, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
-      connect(m_selModel, SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-              this, SLOT(onCurrentChanged(QModelIndex,QModelIndex)));
+              &QItemSelectionModel::selectionChanged,
+              this, &CheckableListModel::onSelectionChanged);
+      connect(m_selModel, &QItemSelectionModel::currentChanged,
+              this, &CheckableListModel::onCurrentChanged);
     }
     emit selectionModelChanged();
   }
@@ -61,7 +57,7 @@ void CheckableListModel::setSelectionModel(QItemSelectionModel* selModel)
 
 void CheckableListModel::setSelectionModelObject(QObject *obj)
 {
-  if (QItemSelectionModel* selModel = qobject_cast<QItemSelectionModel*>(obj)) {
+  if (auto selModel = qobject_cast<QItemSelectionModel*>(obj)) {
     setSelectionModel(selModel);
   }
 }
@@ -96,9 +92,7 @@ bool CheckableListModel::setDataValue(int row, const QByteArray& roleName,
                                       const QVariant& value)
 {
   QHash<int,QByteArray> roleHash = roleNames();
-  for (QHash<int,QByteArray>::const_iterator it = roleHash.constBegin();
-       it != roleHash.constEnd();
-       ++it) {
+  for (auto it = roleHash.constBegin(); it != roleHash.constEnd(); ++it) {
     if (it.value() == roleName) {
       return setData(index(row, 0), value, it.key());
     }
@@ -110,9 +104,7 @@ QVariant CheckableListModel::getDataValue(int row,
                                           const QByteArray& roleName) const
 {
   QHash<int,QByteArray> roleHash = roleNames();
-  for (QHash<int,QByteArray>::const_iterator it = roleHash.constBegin();
-       it != roleHash.constEnd();
-       ++it) {
+  for (auto it = roleHash.constBegin(); it != roleHash.constEnd(); ++it) {
     if (it.value() == roleName) {
       return data(index(row, 0), it.key());
     }
@@ -171,7 +163,7 @@ bool CheckableListModel::setData(const QModelIndex& index,
     if (!m_selModel)
       return false;
 
-    Qt::CheckState state = static_cast<Qt::CheckState>(value.toInt());
+    auto state = static_cast<Qt::CheckState>(value.toInt());
     const QModelIndex srcIndex = mapToSource(index);
     m_selModel->setCurrentIndex(srcIndex, state == Qt::Checked
       ? QItemSelectionModel::Select | QItemSelectionModel::Rows
@@ -189,38 +181,35 @@ void CheckableListModel::setSourceModel(QAbstractItemModel* srcModel)
     emit sourceModelChanged();
 
     if (sourceModel()) {
-      disconnect(sourceModel(), 0, this, 0);
+      disconnect(sourceModel(), nullptr, this, nullptr);
     }
     QAbstractProxyModel::setSourceModel(srcModel);
     if (srcModel) {
-#if QT_VERSION < 0x050000
-      setRoleNames(srcModel->roleNames());
-#endif
-      connect(srcModel, SIGNAL(modelAboutToBeReset()),
-              this, SLOT(onModelAboutToBeReset()));
-      connect(srcModel, SIGNAL(modelReset()),
-              this, SLOT(onModelReset()));
-      connect(srcModel, SIGNAL(layoutAboutToBeChanged()),
-              this, SIGNAL(layoutAboutToBeChanged()));
-      connect(srcModel, SIGNAL(layoutChanged()),
-              this, SIGNAL(layoutChanged()));
-      connect(srcModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-              this, SLOT(onDataChanged(QModelIndex,QModelIndex)));
-      connect(srcModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-              this, SLOT(onRowsAboutToBeRemoved(QModelIndex,int,int)));
-      connect(srcModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-              this, SLOT(onRowsRemoved(QModelIndex,int,int)));
-      connect(srcModel, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-              this, SLOT(onRowsAboutToBeInserted(QModelIndex,int,int)));
-      connect(srcModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-              this, SLOT(onRowsInserted(QModelIndex,int,int)));
+      connect(srcModel, &QAbstractItemModel::modelAboutToBeReset,
+              this, &CheckableListModel::onModelAboutToBeReset);
+      connect(srcModel, &QAbstractItemModel::modelReset,
+              this, &CheckableListModel::onModelReset);
+      connect(srcModel, &QAbstractItemModel::layoutAboutToBeChanged,
+              this, &QAbstractItemModel::layoutAboutToBeChanged);
+      connect(srcModel, &QAbstractItemModel::layoutChanged,
+              this, &QAbstractItemModel::layoutChanged);
+      connect(srcModel, &QAbstractItemModel::dataChanged,
+              this, &CheckableListModel::onDataChanged);
+      connect(srcModel, &QAbstractItemModel::rowsAboutToBeRemoved,
+              this, &CheckableListModel::onRowsAboutToBeRemoved);
+      connect(srcModel, &QAbstractItemModel::rowsRemoved,
+              this, &CheckableListModel::onRowsRemoved);
+      connect(srcModel, &QAbstractItemModel::rowsAboutToBeInserted,
+              this, &CheckableListModel::onRowsAboutToBeInserted);
+      connect(srcModel, &QAbstractItemModel::rowsInserted,
+              this, &CheckableListModel::onRowsInserted);
     }
   }
 }
 
 void CheckableListModel::setSourceModelObject(QObject* obj)
 {
-  if (QAbstractItemModel* srcModel = qobject_cast<QAbstractItemModel*>(obj)) {
+  if (auto srcModel = qobject_cast<QAbstractItemModel*>(obj)) {
     setSourceModel(srcModel);
   }
 }
@@ -285,9 +274,11 @@ void CheckableListModel::onRowsInserted(const QModelIndex& parent,
 void CheckableListModel::onSelectionChanged(const QItemSelection& selected,
                                           const QItemSelection& deselected)
 {
-  foreach (const QItemSelectionRange& range, mapSelectionFromSource(selected))
+  const auto selectedRanges = mapSelectionFromSource(selected);
+  for (const QItemSelectionRange& range : selectedRanges)
     emit dataChanged(range.topLeft(), range.bottomRight());
-  foreach (const QItemSelectionRange& range, mapSelectionFromSource(deselected))
+  const auto deselectedRanges = mapSelectionFromSource(deselected);
+  for (const QItemSelectionRange& range : deselectedRanges)
     emit dataChanged(range.topLeft(), range.bottomRight());
 }
 
