@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Sep 2005
  *
- * Copyright (C) 2005-2013  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -32,16 +32,19 @@ int MusicBrainzConfig::s_index = -1;
 /**
  * Constructor.
  */
-MusicBrainzConfig::MusicBrainzConfig() :
-  StoredConfig<MusicBrainzConfig, ServerImporterConfig>(
-    QLatin1String("MusicBrainz"))
+MusicBrainzConfig::MusicBrainzConfig()
+  : StoredConfig<MusicBrainzConfig, ServerImporterConfig>(
+      QLatin1String("MusicBrainz"))
 {
   setCgiPathUsed(false);
   setAdditionalTagsUsed(true);
-  setServer(QLatin1String("musicbrainz.org:80"));
+  setServer(QLatin1String("musicbrainz.org"));
 }
 
 /**
  * Destructor.
  */
-MusicBrainzConfig::~MusicBrainzConfig() {}
+MusicBrainzConfig::~MusicBrainzConfig()
+{
+  // not inline or default to silence weak-vtables warning
+}
