@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Oct 2006
  *
- * Copyright (C) 2006-2011  Urs Fleisch
+ * Copyright (C) 2006-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MUSICBRAINZIMPORTER_H
-#define MUSICBRAINZIMPORTER_H
+#pragma once
 
 #include "serverimporter.h"
 
@@ -47,42 +46,42 @@ public:
   /**
    * Destructor.
    */
-  virtual ~MusicBrainzImporter();
+  virtual ~MusicBrainzImporter() override = default;
 
   /**
    * Name of import source.
    * @return name.
    */
-  virtual const char* name() const;
+  virtual const char* name() const override;
 
   /** NULL-terminated array of server strings, 0 if not used */
-  virtual const char** serverList() const;
+  virtual const char** serverList() const override;
 
   /** default server, 0 to disable */
-  virtual const char* defaultServer() const;
+  virtual const char* defaultServer() const override;
 
   /** anchor to online help, 0 to disable */
-  virtual const char* helpAnchor() const;
+  virtual const char* helpAnchor() const override;
 
   /** configuration, 0 if not used */
-  virtual ServerImporterConfig* config() const;
+  virtual ServerImporterConfig* config() const override;
 
   /** additional tags option, false if not used */
-  virtual bool additionalTags() const;
+  virtual bool additionalTags() const override;
 
   /**
    * Process finished findCddbAlbum request.
    *
    * @param searchStr search data received
    */
-  virtual void parseFindResults(const QByteArray& searchStr);
+  virtual void parseFindResults(const QByteArray& searchStr) override;
 
   /**
    * Parse result of album request and populate m_trackDataModel with results.
    *
    * @param albumStr album data received
    */
-  virtual void parseAlbumResults(const QByteArray& albumStr);
+  virtual void parseAlbumResults(const QByteArray& albumStr) override;
 
   /**
    * Send a query command to search on the server.
@@ -93,7 +92,7 @@ public:
    */
   virtual void sendFindQuery(
     const ServerImporterConfig* cfg,
-    const QString& artist, const QString& album);
+    const QString& artist, const QString& album) override;
 
   /**
    * Send a query command to fetch the track list
@@ -104,10 +103,8 @@ public:
    * @param id       ID
    */
   virtual void sendTrackListQuery(
-    const ServerImporterConfig* cfg, const QString& cat, const QString& id);
+    const ServerImporterConfig* cfg, const QString& cat, const QString& id) override;
 
 private:
   QMap<QByteArray, QByteArray> m_headers;
 };
-
-#endif
