@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2012
  *
- * Copyright (C) 2012  Urs Fleisch
+ * Copyright (C) 2012-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,8 +25,7 @@
  */
 
 
-#ifndef TESTJSONPARSER_H
-#define TESTJSONPARSER_H
+#pragma once
 
 #include <QTest>
 
@@ -40,5 +39,3 @@ private slots:
   void serializeAndDeserializeTypes();
   void deserializeMusicData();
 };
-
-#endif
